@@ -128,9 +128,11 @@
                 case "DATASET":
                     return "projects.project.datasets.dataset.explore({projectKey: '" + projectKey + "', datasetName: '" + objectId + "'})";
                 case "SAVED_MODEL":
-                    return "projects.project.savedmodels.savedmodel.versions({projectKey: '" + projectKey + "', smId: '" + objectId + "'})";
+                    return StateUtils.uiSref.savedModel(objectId, projectKey);
                 case "MODEL_EVALUATION_STORE":
                     return "projects.project.modelevaluationstores.modelevaluationstore.evaluations({projectKey: '" + projectKey + "', mesId: '" + objectId + "'})";
+                case "GENAI_EVALUATION_STORE":
+                    return "projects.project.genaievaluationstores.genaievaluationstore.evaluations({projectKey: '" + projectKey + "', mesId: '" + objectId + "'})";
                 case "MANAGED_FOLDER":
                     return "projects.project.managedfolders.managedfolder.view({projectKey: '" + projectKey + "', odbId: '" + objectId + "'})";
                 case "PLUGIN":
