@@ -176,6 +176,17 @@ app.directive("analysisPredictedChartsBase", function($q, $timeout, Assert, Data
                 }
             };
 
+            $scope.getLLMChartContext = function() {
+                return {
+                    context: "predicted",
+                    fullModelId: $stateParams.fullModelId,
+                    getSuggestionsCacheKey(chartDefCacheKey) {
+                        return chartDefCacheKey ? $stateParams.fullModelId + chartDefCacheKey : $stateParams.fullModelId;
+                    }
+
+                };
+            };
+
             $scope.getDefaultNewChart = function() {
                 const defaultTheme = DSSVisualizationThemeUtils.getThemeOrDefault($rootScope.appConfig.selectedDSSVisualizationTheme);
                 return {
