@@ -685,7 +685,7 @@ app.controller('CatalogItemsController', function($controller, $scope, $state, $
     init();
 });
 
-app.service('CatalogRefreshUtils', function($state, StateUtils) {
+app.service('CatalogRefreshUtils', function($state, StateUtils, SmartId) {
     function breakFlowComputableNameIntoParts(name) {
         const parts = name.split('.');
         if (parts.length === 1) return {name: name};
@@ -742,41 +742,36 @@ app.service('CatalogRefreshUtils', function($state, StateUtils) {
         });
     }
 
+
+    // currentProjectKey is not exactly the contextProjectKey as often used when working with foreign objects
+    // usually, the contextProjectKey is the project we are currently navigating in, and it defaults to ActiveProjectKey when omitted.
+    // this method is used in the related items components in the old catalog (now search DSS screen / inbox) and the feature store, which are not in any project
+    // In this method currentProjectKey is the project for the object we are displaying the related object of.
+    // Related items will be opened using that object's project as context project, using a foreign view when available and relevant.
+    // consider using StateUtils.dssObject, this method is way too spaghetti already
     function getLinkForElement(currentProjectKey, element) {
-        const projectKey = element.projectKey || currentProjectKey;
+        // fullName when in the old catalog recipe io or related objects, name when in the feature store.
+        // except for evaluation store recipe output in the old catalog where for some reason name is actually the name, and there is also an id
+        const ref = SmartId.resolve(element.fullName || element.id || element.name, currentProjectKey);
+        const smartId = SmartId.create(ref.id, ref.projectKey, currentProjectKey);
         switch (element.type) {
             case "DATASET":
-                if (element.projectKey && element.projectKey !== currentProjectKey) {
-                    return $state.href("projects.project.foreigndatasets.dataset.explore", {
-                        datasetFullName: element.datasetFullName,
-                        projectKey: currentProjectKey
-                    });
-                } else {
-                    return $state.href("projects.project.datasets.dataset.explore", {
-                        datasetName: element.name, projectKey: projectKey
-                    });
-                }
+                return StateUtils.href.dataset(smartId, currentProjectKey);
             case "SAVED_MODEL":
-                return $state.href("projects.project.savedmodels.savedmodel.versions", {
-                    smId: element.name,
-                    projectKey: projectKey
-                });
+                return StateUtils.href.savedModel(smartId, currentProjectKey);
             case "MODEL_EVALUATION_STORE":
-                return StateUtils.href.modelEvaluationStore(element.name, projectKey);
+                return StateUtils.href.modelEvaluationStore(smartId, currentProjectKey);
             case "MANAGED_FOLDER":
-                return $state.href("projects.project.managedfolders.managedfolder.view", {
-                    odbId: element.name,
-                    projectKey: projectKey
-                });
+                return StateUtils.href.managedFolder(ref.id, ref.projectKey, currentProjectKey);
             case "STREAMING_ENDPOINT":
                 return $state.href("projects.project.streaming-endpoints.streaming-endpoint.settings", {
-                    streamingEndpointId: element.name,
-                    projectKey: projectKey
+                    projectKey: ref.projectKey,
+                    streamingEndpointId: ref.id
                 });
             case "RETRIEVABLE_KNOWLEDGE":
                return $state.href("projects.project.retrievableknowledges.retrievableknowledge.settings", {
-                   projectKey,
-                   retrievableKnowledgeId: element.id,
+                   projectKey: ref.projectKey,
+                   retrievableKnowledgeId: ref.id,
                    '#': 'core-settings',
                });
             default:
@@ -793,7 +788,7 @@ app.service('CatalogRefreshUtils', function($state, StateUtils) {
     };
 });
 
-app.component('relatedByType', {
+app.component('relatedByType', { // related-by-type
     template: `
         <div class="accordion" ng-repeat="(type, elements) in $ctrl.elementsByType">
             <h4 class="accordion-title" ng-click="show=!show">
@@ -822,10 +817,10 @@ app.component('relatedByType', {
 });
 
 
-app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuAPI, CachedAPICalls, $sce,
-                                                    CatalogItemService, ActivityIndicator, ExposedObjectsService,
-                                                    AppConfig, FLOW_COMPUTABLE_TYPES, CatalogRefreshUtils,
-                                                    QuickSharingWT1EventsService, SavedModelsService, AgentToolEnrichmentService) {
+app.controller('CatalogRefreshController', function($scope, DataikuAPI, CachedAPICalls,
+                                                    CatalogItemService, Ng2ObjectsExpositionService,
+                                                    FLOW_COMPUTABLE_TYPES, CatalogRefreshUtils,
+                                                    SavedModelsService, AgentToolEnrichmentService) {
     $scope.getLinkForElement = CatalogRefreshUtils.getLinkForElement;
 
     $scope.resolveObjectSmartId = resolveObjectSmartId;
@@ -878,7 +873,7 @@ app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuA
                     item.creatingContinuousRecipe = response.creatingContinuousRecipe;
                     item.creatingLabelingTask = response.creatingLabelingTask;
 
-                    SavedModelsService.enrichSavedModelObject(item, $scope)
+                    SavedModelsService.enrichSavedModelObject(item, undefined, $scope)
                 })
                 .error(setErrorInScope.bind($scope));
         } else if (item._type === 'agent_tool') {
@@ -906,62 +901,19 @@ app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuA
         item.highlightedPartitionColumns = CatalogRefreshUtils.highlightedColumnList(item, item._source.partitioning);
 
         const exposable = FLOW_COMPUTABLE_TYPES.includes(taggableType);
-        const targetProjectDefined = !!$scope.projectKey;
         const selectedItemSource = item._source;
 
-        const exposeObjectToTargetProjectFn = () => {
-            ExposedObjectsService.doExposeSingleObject(
-                taggableType,
-                selectedItemSource.projectKey,
-                selectedItemSource.id,
-                $scope.projectKey,
-                selectedItemSource.name,
-                selectedItemSource.isQuicklyShareable,
-                true
-            ).error(setErrorInScope.bind($scope.getCatalogScope()));
-        };
         const exposeObjectToProjectsFn = (canManageExposedElements) =>
-            () => ExposedObjectsService.openSingleObjectUseModal(taggableType, selectedItemSource.id, selectedItemSource.name, selectedItemSource.projectKey, canManageExposedElements ,{from: 'search-dss'});
+            () => Ng2ObjectsExpositionService.openSingleObjectUseModal(taggableType, selectedItemSource.id, selectedItemSource.name, selectedItemSource.projectKey, canManageExposedElements ,{from: 'search-dss'});
 
         const requestSharingFn =
-            () => ExposedObjectsService.requestSharing(taggableType, selectedItemSource.id, selectedItemSource.name, selectedItemSource.projectKey, $scope.projectKey, {from: 'search-dss'})
+            () => Ng2ObjectsExpositionService.requestSharing(taggableType, selectedItemSource.id, selectedItemSource.name, selectedItemSource.projectKey, $scope.projectKey, {from: 'search-dss'})
 
         $scope.exposeObjectFn = null;
         $scope.exposeLabel = null;
         $scope.importLbl = 'Use';
         $scope.exposeIcon = 'icon-dku-share';
 
-        function checkObjectExpositionInsideProject(projectKey, objectType, objectId) {
-            DataikuAPI.projects.getObjectAuthorizations(projectKey, objectType, objectId).success((data) => {
-                if (data.isQuicklyShareable) {
-                    $scope.exposeDisabled = !data.canReadObject;
-                    if (data.canReadObject) {
-                        $scope.exposeLabel = 'Use in project ' + $scope.projectKey;
-                        $scope.importLbl = 'Use';
-                    } else {
-                        $scope.exposeLabel = 'No permission to share object';
-                    }
-                } else {
-                    $scope.exposeDisabled = !data.canManageExposedElements && !data.isObjectSharingRequestEnabled;
-                    if (data.canManageExposedElements) {
-                        $scope.exposeLabel = 'Use in project ' + $scope.projectKey;
-                        $scope.importLbl = 'Use';
-                    } else if (data.isObjectSharingRequestEnabled) {
-                        $scope.exposeObjectFn = requestSharingFn;
-                        $scope.exposeIcon = "icon-lock";
-                        $scope.exposeLabel = 'Request to use in project ' + $scope.projectKey;
-                        $scope.importLbl = 'Request';
-                    } else {
-                        $scope.exposeLabel = 'No permission to share object';
-                    }
-                }
-            }).error(function (response, status, headers) {
-                $scope.exposeDisabled = true;
-                $scope.exposeLabel = 'No permission to share object';
-                setErrorInScope.bind($scope.getCatalogScope())(response, status, headers);
-            })
-        }
-
         const checkObjectExposition= function(projectKey, objectType, objectId) {
             DataikuAPI.projects.getObjectAuthorizations(projectKey, objectType, objectId).success((data) => {
                 $scope.exposeObjectFn = exposeObjectToProjectsFn(data.canManageExposedElements);
@@ -993,21 +945,8 @@ app.controller('CatalogRefreshController', function($scope, $rootScope, DataikuA
         }
 
         if (exposable) {
-            if (targetProjectDefined) {
-                $scope.exposeObjectFn = exposeObjectToTargetProjectFn;
-                if ($scope.projectKey === selectedItemSource.projectKey) {
-                    $scope.exposeLabel = 'Target project must be different from source';
-                    $scope.exposeDisabled = true;
-                } else if (selectedItemSource.usedIn && selectedItemSource.usedIn.includes($scope.projectKey)) {
-                    $scope.exposeLabel = 'Object already shared';
-                    $scope.exposeDisabled = true;
-                } else {
-                    checkObjectExpositionInsideProject(item._source.projectKey, taggableType, item._source.id);
-                }
-            } else {
-                $scope.exposeObjectFn = exposeObjectToProjectsFn(false); // this is just a temp value while actual authorization is fetched in checkObjectExposition
-                checkObjectExposition(item._source.projectKey, taggableType, item._source.id);
-            }
+            $scope.exposeObjectFn = exposeObjectToProjectsFn(false); // this is just a temp value while actual authorization is fetched in checkObjectExposition
+            checkObjectExposition(item._source.projectKey, taggableType, item._source.id);
         }
 
         // Filter "Related final" section
