@@ -6,7 +6,7 @@ const app = angular.module('dataiku.code-studios', [])
 
 app.controller("CodeStudiosCommonController", function($scope, $state, $rootScope, $stateParams, $q, $controller, TopNav, CodeStudiosService, LoggerProvider, WT1,
                                                     DataikuAPI, FutureWatcher, Dialogs, ActivityIndicator, TAIL_STATUS, DKUtils, StateUtils, PluginsService,
-                                                    ActiveProjectKey, FutureProgressModal, CreateModalFromTemplate) {
+                                                    ActiveProjectKey, FutureProgressModal, CreateModalFromTemplate, SpinnerService) {
 
     $scope.hooks = $scope.hooks || {};
 
@@ -54,13 +54,24 @@ app.controller("CodeStudiosCommonController", function($scope, $state, $rootScop
         return deferred.promise;
     }
 
+    function handlePullResponse(response) {
+        const result = response.data;
+        if (result && result.jobId && !result.hasResult) {
+            return FutureWatcher.watchJobId(result.jobId)
+                .then(data => data);
+        } else {
+            return result;
+        }
+    }
+
     function doForcePullEverything(codeStudioObject) {
         WT1.event("code_studio_action_syncstop", {type:codeStudioObject.templateId});
         let deferred = $q.defer();
         DataikuAPI.codeStudioObjects.getState($stateParams.projectKey, codeStudioObject.id).success(function(result) {
             let syncedZones = result.syncedZones;
             const promises = syncedZones.map(z => {
-                return DataikuAPI.codeStudioObjects.pullBundle($stateParams.projectKey, codeStudioObject.id, z.id, true);
+                return DataikuAPI.codeStudioObjects.pullBundle($stateParams.projectKey, codeStudioObject.id, z.id, true)
+                    .then(handlePullResponse);
             });
             $q.all(promises)
                 .then(responses => {
@@ -210,27 +221,32 @@ app.controller("CodeStudiosCommonController", function($scope, $state, $rootScop
     $scope.doPull = function(projectKey, codeStudioObjectId, selectedOptions) {
         let deferred = $q.defer();
         const promises = selectedOptions.map(opt => {
-            return DataikuAPI.codeStudioObjects.pullBundle(projectKey, codeStudioObjectId, opt.name, true);
+            return DataikuAPI.codeStudioObjects.pullBundle(projectKey, codeStudioObjectId, opt.name, true)
+                .then(handlePullResponse);
         });
         //if we are in the kubikle runtime page, we have to handle the UI state
         //that we don't have from the kubikles list page
         if ($scope.uiState) {
             delete $scope.uiState['pullSyncOK'];
             $scope.uiState.syncing = 'pull';
-            $q.all(promises)
-                .then(responses => {
-                    $scope.uiState['pullSyncOK'] = true;
-                    setTimeout(() => delete $scope.uiState['pullSyncOK'], 2000);
-                    $scope.uiState['pullSyncLog'] = `Last sync ${(new Date()).toLocaleTimeString()}`;
-                    deferred.resolve(responses);
-                }, error => {
-                    ActivityIndicator.error("Synchronization failed");
-                    $scope.uiState['pullSyncOK'] = false;
-                    $scope.uiState['pullSyncLog'] = `Last sync ${(new Date()).toLocaleTimeString()} failed: ${error.message}`;
-                    deferred.reject(error);
-                }).finally(() => { $scope.uiState.syncing = null; });
+            SpinnerService.lockOnPromise(
+                $q.all(promises)
+                    .then(responses => {
+                        $scope.uiState['pullSyncOK'] = true;
+                        setTimeout(() => delete $scope.uiState['pullSyncOK'], 2000);
+                        $scope.uiState['pullSyncLog'] = `Last sync ${(new Date()).toLocaleTimeString()}`;
+                        deferred.resolve(responses);
+                    }, error => {
+                        ActivityIndicator.error("Synchronization failed");
+                        $scope.uiState['pullSyncOK'] = false;
+                        $scope.uiState['pullSyncLog'] = `Last sync ${(new Date()).toLocaleTimeString()} failed : ${error.message}`;
+                        deferred.reject(error);
+                    }).finally(() => { $scope.uiState.syncing = null; })
+            );
         } else {
-            $q.all(promises).then(deferred.resolve, deferred.reject);
+            SpinnerService.lockOnPromise(
+                $q.all(promises).then(deferred.resolve, deferred.reject)
+            );
         }
         return deferred.promise;
     }
@@ -663,10 +679,6 @@ app.controller("CodeStudioCoreController", function($scope, $rootScope, $statePa
         return deferred.promise;
     };
 
-    $scope.getBackendLogURL = function(app) {
-        return DataikuAPI.codeStudioObjects.getBackendLogURL(app.projectKey, app.id);
-    };
-
     $scope.duplicateCodeStudio = function() {
         $scope.saveCodeStudio().then(function() {
             CodeStudiosService.duplicate($scope, $scope.codeStudioObject);
@@ -759,6 +771,10 @@ app.controller("CodeStudioCoreController", function($scope, $rootScope, $statePa
         $scope.zoneToPrepareForEdit = zoneToPrepare;
     }
 
+    $scope.refreshLogs = function(){
+        $scope.$broadcast('refreshRunLogs');
+    };
+
     $scope.refreshState = function() {
         DataikuAPI.codeStudioObjects.getState($stateParams.projectKey, $stateParams.codeStudioObjectId).success(function(result) {
             $scope.codeStudioState = result;
@@ -785,6 +801,8 @@ app.controller("CodeStudioCoreController", function($scope, $rootScope, $statePa
                 // do more refreshing
                 stopAutoRefresh();
                 cancelRefresh = $timeout($scope.refreshState, 2000);
+            } else {
+                $scope.refreshLogs();
             }
         }).error(setErrorInScope.bind($scope));
         $scope.$broadcast("refreshState"); // so that sub-controllers can also refresh their things
@@ -1046,16 +1064,14 @@ app.controller("CodeStudioLogsController", function($scope, $rootScope, $statePa
     
     $scope.uiState.active = $stateParams.tab || $scope.uiState.active || 'main_log';
     $scope.uiState.files = {path:'.', exists:false, children:[], preview:{}};
+    $scope.projectKey = $stateParams.projectKey;
+    $scope.codeStudioObjectId = $stateParams.codeStudioObjectId;
     
     $scope.startCodeStudio = function() {
         WT1.event("code_studio_action_start", {type:$scope.codeStudioObject.templateId});
         $scope.restartWaitAndShowError($scope.codeStudioObject.id).then($scope.refreshRunInfo, $scope.refreshRunInfo);
     };
     
-    $scope.getLogURL = function() {
-        return DataikuAPI.codeStudioObjects.getLogURL($stateParams.projectKey, $stateParams.codeStudioObjectId);
-    };
-    
     $scope.refreshRunInfo = function() {
         DataikuAPI.codeStudioObjects.getRunInfo($stateParams.projectKey, $stateParams.codeStudioObjectId).success(function(result) {
             $scope.codeStudioRunInfo = result;
@@ -1067,27 +1083,6 @@ app.controller("CodeStudioLogsController", function($scope, $rootScope, $statePa
     
     $scope.$on("refreshState", $scope.refreshRunInfo);
 
-    $scope.refreshLogs = function() {
-        if (!$scope.codeStudioRunInfo.jobId) return;
-        WT1.event("code_studio_action_refresh", {type: $scope.codeStudioObject.templateId});
-        DataikuAPI.futures.getUpdate($scope.codeStudioRunInfo.jobId).success(function(result) {
-            $scope.codeStudioRunInfo.logTail = result.log;
-        }).error(function(data, status, headers, config, statusText, xhrStatus) {
-            // check if it's not a "this CodeStudio has been restarted" issue
-            if ((data.message || '').indexOf("JobID not found :") >= 0) {
-                Logger.info("Code Studio appears to have been restarted");
-                $scope.refreshRunInfo();
-            } else {
-                setErrorInScope.bind($scope)(data, status, headers, config, statusText, xhrStatus);
-            }
-        });
-    };
-
-    $scope.downloadDiagnosis = function() {
-        ActivityIndicator.success("Preparing Code Studio diagnosis ...");
-        downloadURL(DataikuAPI.codeStudioObjects.getDiagnosisURL($stateParams.projectKey, $stateParams.codeStudioObjectId));
-    };
-
     $scope.setLogTab = function(tabname) {
         $scope.uiState.active = tabname;
         if (tabname === 'files') {
@@ -1391,11 +1386,56 @@ app.service('CodeStudiosService', function($rootScope, DataikuAPI, CreateModalFr
                     "projects.project.code-studios.list"
                 )
             }
-            DataikuAPI.codeStudioObjects.listHeads($stateParams.projectKey).success(function(data) {
-                newScope.codeStudioObjects = data.items.filter(e => !e.templateWasDeleted || e.uiState.state !== 'STOPPED');
-            }).error(setErrorInScope.bind(scope));
+
             newScope.selectedCodeStudioId = localStorageService.get(CSIO_FAVORITE_EDITOR_KEY);
 
+            DataikuAPI.codeStudioObjects.listHeads($stateParams.projectKey).success(function(data) {
+                let codeStudioExists = false;
+
+                const templateSyncsZone = (cso) => cso.syncedZones.find(synced => synced.zone == zone);
+
+                const usableCodeStudios = data.items
+                    .filter(item => !item.templateWasDeleted || item.uiState.state !== 'STOPPED');
+
+                const syncingCodeStudios = usableCodeStudios
+                    .filter(item => templateSyncsZone(item))
+                    .map(item => {
+                        if (item.id == newScope.selectedCodeStudioId) {
+                            codeStudioExists = true;
+                        }
+                        return {
+                            name: item.name,
+                            templateLabel: item.desc.label,
+                            templateId: item.templateId,
+                            id: item.id
+                        }
+                    }
+                );
+
+                // append templates not synchronizing selected zone so the user knows what to do
+                const nonSynchronizingTemplates = data.items.filter(item => !templateSyncsZone(item))
+                    .reduce((acc, item) => {
+                        const label = item.desc.label;
+                        if (!acc[label]) {
+                            acc[label] = {
+                                name: `This Code Studio template does not synchronize ${zone} files`,
+                                templateLabel: label + ' - unavailable',
+                                templateId: item.templateId,
+                                id: item.id,
+                                disabled: true
+                            };
+                        }
+                        return acc;
+                    }, {});
+
+                newScope.codeStudioObjects = Object.values(nonSynchronizingTemplates).concat(syncingCodeStudios);
+
+                if (!codeStudioExists) {
+                    newScope.selectedCodeStudioId = (syncingCodeStudios.length > 0) ? syncingCodeStudios[0].id : null;
+                }
+
+            }).error(setErrorInScope.bind(scope));
+
             newScope.go = function() {
                 localStorageService.set(CSIO_FAVORITE_EDITOR_KEY, newScope.selectedCodeStudioId);
                 const selectedCodeStudio = newScope.codeStudioObjects.find(e => e.id === newScope.selectedCodeStudioId);
