@@ -133,6 +133,7 @@
                 }
                 return getFilterFacets(newFilters, options.disableLoadingIndicator)
                     .then((filterFacets) => {
+                        DashboardFilters.setDashboardFiltersFacets(filterFacets, ctrl.page.cid);
                         ctrl.filterFacets = filterFacets;
 
                         if (filterFacets == null) {
@@ -373,18 +374,12 @@
             function handleDrillFilterAddedEvent({ filter }) {
                 // hasMatchingColumn is necessary to allow the filter to update other dashboard filter facets.
                 const hasMatchingColumn = !!CrossFiltersService.getMatchingColumn(filter, ctrl.usableColumns);
-                const newFilters = [
-                    ...ctrl.filters,
-                    {
-                        ...filter,
-                        hasMatchingColumn
-                    }
-                ];
+                const newFilters = ChartFilters.updateOrAddHierarchyFilter(ctrl.filters, filter, hasMatchingColumn);
                 ctrl.handleFiltersChange(newFilters, { hasSamplingParamsChanged: false, disableLoadingIndicator: false, canPropagageBeforeFacetUpdate: true });
             }
 
-            function handleDrillFilterRemovedEvent({ filterId }) {
-                const newFilters = ctrl.filters.filter(filter => filter.id !== filterId);
+            function handleDrillFilterRemovedEvent({ filterIds }) {
+                const newFilters = ctrl.filters.filter(f => !filterIds.includes(f.id));
                 ctrl.handleFiltersChange(newFilters, { hasSamplingParamsChanged: false, disableLoadingIndicator: false, canPropagageBeforeFacetUpdate: true });
             }
 
