@@ -1,4 +1,4 @@
-(function(){
+(function() {
     'use strict';
 
     const app = angular.module('dataiku.dashboards');
@@ -10,7 +10,7 @@
     app.controller('DashboardEditController', function($scope, $state, $timeout, DashboardFilters,
         DataikuAPI, CreateModalFromTemplate, Dialogs, TopNav, INSIGHT_TYPES, DSSVisualizationThemeUtils,
         TileUtils, ActivityIndicator, DashboardUtils, $rootScope, ATSurveyService, WT1, FiltersPanelPosition, StateUtils,
-        DashboardPageUtils) {
+        DashboardPageUtils, DashboardVariablesService) {
         TopNav.setLocation(TopNav.TOP_DASHBOARD, 'dashboards', null, 'edit');
 
         if ($scope.dashboard) {
@@ -31,6 +31,12 @@
 
         DashboardUtils.toggleAllFilterPanels($scope.dashboard, true);
 
+        const variablesSubscription = DashboardVariablesService.getVariables($scope.dashboard.projectKey).subscribe(
+            vars => {
+                $scope.variables = vars;
+            }
+        );
+
         $scope.$on('dashboardSyncModelsDone', function() {
             const insightIdSet = retrieveInsightIdSetFromDashboard($scope.dashboard);
             $scope.hasFilterTile = alreadyHaveGlobalFilters();
@@ -58,6 +64,16 @@
             }
         });
 
+        $scope.showNewTile = false;
+        $scope.$watchGroup(
+            ['dashboard.pages', 'uiState.currentPageIdx', 'dashboard.pages[uiState.currentPageIdx].grid.tiles'],
+            function([newPages, newPageIdx]) {
+                const newPage = newPages[newPageIdx];
+                const newTiles = newPage ? newPage.grid.tiles : [];
+                $scope.showNewTile = newTiles.filter(tile => !TileUtils.isTitleTile(tile)).length !== 0;
+            }
+        );
+
         $scope.createNewTile = function() {
             CreateModalFromTemplate('/templates/dashboards/insights/new-insight-modal.html', $scope, 'NewInsightModalController', function(modalScope) {
                 modalScope.withSimpleTiles = true;
@@ -90,7 +106,7 @@
                     });
                 };
                 modalScope.isInsightInDashboard = function(insight) {
-                    return typeof($scope.insightsMap[insight.id]) !== 'undefined';
+                    return typeof ($scope.insightsMap[insight.id]) !== 'undefined';
                 };
             }, undefined, 'static', false).then(function(ret) {
                 if (ret.tileType) { // simple tile
@@ -136,7 +152,7 @@
         $scope.addFilterTileToPage = function() {
             const filterInsight = {
                 type: 'filters',
-                name:'Filters',
+                name: 'Filters',
                 params: {},
                 dashboardCreationId: $scope.dashboard.id,
                 projectKey: $scope.dashboard.projectKey,
@@ -243,6 +259,7 @@
                 newScope.pageIdx = pageIdx;
                 newScope.uiState = $scope.uiState;
                 newScope.insightsMap = $scope.insightsMap;
+                newScope.variables = $scope.variables;
                 newScope.init();
             });
         };
@@ -281,21 +298,6 @@
             $scope.uiState.selectedTile = tile;
         };
 
-        // TODO: factorize with tile-params directive
-        $scope.getDefaultTileTitle = (tile, insight) => {
-            if (!tile) {
-                return '';
-            }
-            switch (tile.tileType) {
-                case 'INSIGHT':
-                    return (insight || {}).name;
-                case 'TEXT':
-                    return 'Text tile';
-                case 'IMAGE':
-                    return 'Image tile';
-            }
-        };
-
         $scope.copyURL = (urlToCopy) => {
             DashboardUtils.copyToClipboard(urlToCopy);
         };
@@ -303,7 +305,7 @@
         $scope.$on('$viewContentLoaded', () => {
             // Action requested from view mode
             if ($scope.editActionRequested) {
-                switch($scope.editActionRequested.type) {
+                switch ($scope.editActionRequested.type) {
                     case 'create':
                         $scope.createPage();
                         break;
@@ -334,6 +336,7 @@
             if (unregisterDashboardUnselectTilesEvent != null) {
                 unregisterDashboardUnselectTilesEvent();
             }
+            variablesSubscription.unsubscribe();
         });
 
         function alreadyHaveGlobalFilters() {
@@ -350,9 +353,9 @@
                     insightIdsSet.add(currentTile.insightId);
                 }
                 if (TileUtils.isGroupTile(currentTile) &&
-                        currentTile.grid != null &&
-                        currentTile.grid.tiles != null &&
-                        currentTile.grid.tiles.length > 0) {
+                    currentTile.grid != null &&
+                    currentTile.grid.tiles != null &&
+                    currentTile.grid.tiles.length > 0) {
                     stack.push(...currentTile.grid.tiles);
                 }
             }
