@@ -1265,7 +1265,7 @@ app.directive('multiBuildSupport', function($stateParams, DataikuAPI, Dialogs, C
         restrict: 'AE',
         link : function(scope, element, attrs) {
 
-            function openMultiBuildModal(errorMessage, defaultLimitToZone) {
+            function openMultiBuildModal(errorMessage, defaultLimitToZone, originalBuildContext) {
                 return function(data) {
                     if (!data.length) {
                         Dialogs.error(scope, "Nothing to build", errorMessage);
@@ -1275,7 +1275,7 @@ app.directive('multiBuildSupport', function($stateParams, DataikuAPI, Dialogs, C
                             scope,
                             "BuildMultipleComputablesController",
                             function(modalScope) {
-                                modalScope.initModal(data);
+                                modalScope.initModal(data, undefined, originalBuildContext);
                                 modalScope.jobOptions.stopAtFlowZoneBoundary = defaultLimitToZone;
                             }
                         );
@@ -1285,7 +1285,7 @@ app.directive('multiBuildSupport', function($stateParams, DataikuAPI, Dialogs, C
 
             scope.buildZone = function(zoneId) {
                 DataikuAPI.flow.listDownstreamComputables($stateParams.projectKey, {zoneId: zoneId})
-                    .success(openMultiBuildModal("This zone has no buildable dataset.", true))
+                    .success(openMultiBuildModal("This zone has no buildable dataset.", true, { origin: "FLOW_ZONE"}))
                     .error(setErrorInScope.bind(scope));
             }
 
