@@ -5,8 +5,8 @@ const app = angular.module('dataiku.managedfolder', ['dataiku.datasets.upload'])
 
 
 app.service('ManagedFolderDownloadService', function($stateParams, DataikuAPI, CreateModalFromTemplate, FutureWatcher, ProgressStackMessageBuilder) {
-    this.downloadFolder = function (scope, path) {
-        DataikuAPI.managedfolder.startDownloadFolder($stateParams.projectKey, scope.odb.projectKey, scope.odb.id, path)
+    const monitorDownloadJob = function (scope, promise) {
+        promise
             .success(function (initialResponse) {
                 CreateModalFromTemplate("/templates/projects/export-progress-modal.html", scope, null, function (progressScope) {
                     progressScope.modalName = "Managed folder";
@@ -36,13 +36,24 @@ app.service('ManagedFolderDownloadService', function($stateParams, DataikuAPI, C
                             setErrorInScope.bind(progressScope)(data, status, headers);
                         });
                 });
-            }).error(setErrorInScope.bind(scope));;
+            })
+            .error(setErrorInScope.bind(scope));
+    };
+
+    this.downloadFolder = function (scope, path) {
+        const promise = DataikuAPI.managedfolder.startDownloadFolder($stateParams.projectKey, scope.odb.projectKey, scope.odb.id, path);
+        monitorDownloadJob(scope, promise);
+    };
+
+    this.downloadSelectedFiles = function(scope, paths) {
+        const promise = DataikuAPI.managedfolder.startDownloadSelectedFiles($stateParams.projectKey, scope.odb.projectKey, scope.odb.id, paths);
+        monitorDownloadJob(scope, promise);
     };
 });
 
 app.directive('managedFolderRightColumnSummary', function ($state, $controller, $stateParams, $rootScope, TopNav, FlowGraphSelection, FlowBuildService,
     DataikuAPI, ComputablesService, CreateModalFromTemplate, QuickView, ActiveProjectKey, ActivityIndicator, AnyLoc, SelectablePluginsService, ManagedFolderDownloadService,
-    ManagedFolderRenameService) {
+    ManagedFolderRenameService, PluginCategoryService) {
     return {
         templateUrl :'/templates/managedfolder/right-column-summary.html',
 
@@ -139,6 +150,7 @@ app.directive('managedFolderRightColumnSummary', function ($state, $controller,
             };
 
             scope.selectablePlugins = SelectablePluginsService.listSelectablePlugins({'MANAGED_FOLDER' : 1});
+            scope.noRecipesCategoryPlugins = PluginCategoryService.standardCategoryPlugins(scope.selectablePlugins, ['visual', 'code'])
 
             scope.$on("objectSummaryEdited", function() {
                 DataikuAPI.managedfolder.save(scope.odb, {summaryOnly: true})
@@ -160,13 +172,13 @@ app.directive('managedFolderRightColumnSummary', function ($state, $controller,
                     });
             };
 
-            scope.editCustomFields = function() {
+            scope.editCustomFields = function(editingTabIndex = 0) {
                 DataikuAPI.managedfolder.get(scope.odb.projectKey, scope.odb.projectKey, scope.odb.id).success(function(data) {
                     let managedFolder = data;
                     if (!managedFolder) {
                         return;
                     }
-                    let modalScope = angular.extend(scope, {objectType: 'MANAGED_FOLDER', objectName: managedFolder.name, objectCustomFields: managedFolder.customFields});
+                    let modalScope = angular.extend(scope, {objectType: 'MANAGED_FOLDER', objectName: managedFolder.name, objectCustomFields: managedFolder.customFields, editingTabIndex});
                     CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
                         scope.saveCustomFields(customFields);
                     });
@@ -249,13 +261,13 @@ app.controller("ManagedFolderBaseController", function($scope, $state, $statePar
             });
     };
 
-    $scope.editCustomFields = function() {
+    $scope.editCustomFields = function(editingTabIndex = 0) {
         DataikuAPI.managedfolder.get(ActiveProjectKey.get(), ActiveProjectKey.get(), $stateParams.odbId).success(function(data) {
             let managedFolder = data;
             if (!managedFolder) {
                 return;
             }
-            let modalScope = angular.extend($scope, {objectType: 'MANAGED_FOLDER', objectName: managedFolder.name, objectCustomFields: managedFolder.customFields});
+            let modalScope = angular.extend($scope, {objectType: 'MANAGED_FOLDER', objectName: managedFolder.name, objectCustomFields: managedFolder.customFields, editingTabIndex});
             CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
                 $scope.saveCustomFields(managedFolder, customFields);
             });
@@ -291,7 +303,7 @@ app.controller("ManagedFolderPageRightColumnActions", async function($controller
 });
 
 
-app.controller("NewManagedFolderController", function($scope, $state, DataikuAPI, WT1, $stateParams) {
+app.controller("NewManagedFolderController", function($scope, $state, DataikuAPI, WT1, $stateParams, ConnectionsService) {
     WT1.event("new-managed-folder-modal-open");
 
     $scope.newBox = {
@@ -307,6 +319,8 @@ app.controller("NewManagedFolderController", function($scope, $state, DataikuAPI
         $scope.newBox.settings.typeOptionId = $scope.newBox.settings.$connection.fsProviderTypes[0];
     }
 
+    $scope.searchConnectionsWithDescriptions = ConnectionsService.searchConnectionsWithDescriptions;
+
     DataikuAPI.datasets.getManagedFolderOptionsNoContext($stateParams.projectKey).success(function(data) {
         $scope.managedDatasetOptions = data;
         $scope.managedDatasetOptions.connections = $scope.managedDatasetOptions.connections.filter(function(c) {return c.fsProviderTypes != null;});
@@ -575,7 +589,7 @@ app.directive('managedFolderContentsView', function(DataikuAPI, $rootScope, Crea
 
             if (!$stateParams.fromFlow) {
                 // Do not change the focus item zoom if coming from flow
-                GraphZoomTrackerService.setFocusItemByName("managedfolder", $stateParams.odbId);
+                GraphZoomTrackerService.setFocusItemById("managedfolder", $stateParams.odbId);
             }
 
             /*
@@ -1155,6 +1169,11 @@ app.directive('managedFolderContentsView', function(DataikuAPI, $rootScope, Crea
                 ManagedFolderDownloadService.downloadFolder($scope, path);
             };
 
+            $scope.downloadSelectedItems = function (items) {
+                const paths = items.map(item => item.fullPath);
+                ManagedFolderDownloadService.downloadSelectedFiles($scope, paths);
+            };
+
             /*
              * Skins
              */
@@ -1571,6 +1590,7 @@ app.directive('managedFolderContentsList', function(DataikuAPI, CreateModalFromT
                 } else {
                     template += `
                         <li><a ng-click="moveItems(items)">Move to...</a></li>
+                        <li><a ng-click="downloadSelectedItems(items)">Download</a></li>
                         <li><a ng-click="deleteItems(items, $event)" style="border-top: 1px #eee solid;">Delete...</a></li>
                     `;
                 }
