@@ -5,95 +5,6 @@
 const app = angular.module('dataiku.projects.settings');
 
 
-app.service('ExposedObjectsService', function($rootScope, $stateParams, TaggableObjectsService, CreateModalFromTemplate, DataikuAPI, QuickSharingWT1EventsService, StateUtils, ActivityIndicator) {
-
-    this.exposeObjects = function(items) {
-        return CreateModalFromTemplate("/templates/projects/expose-objects-modal.html", $rootScope, "ExposeObjectsModalController", function(modalScope) {
-            modalScope.init(items);
-        });
-    };
-
-    function openSingleObjectModal(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, displayMode, wt1Context) {
-        // TODO : candidate for Angular migration
-        return CreateModalFromTemplate("/templates/projects/expose-single-object-modal.html", $rootScope, "ExposeSingleObjectModalController", function(modalScope) {
-            modalScope.init(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, displayMode, wt1Context);
-        });
-    }
-
-    // warning: canManageExposedElements is related to the object - it might not be the current project canManageExposedElements if object is already foreign
-    this.openSingleObjectShareModal = (objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, wt1Context) => {
-        return openSingleObjectModal(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, 'share', wt1Context);
-    }
-
-    this.openSingleObjectUseModal = (objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, wt1Context) => {
-        return openSingleObjectModal(objectType, objectId, objectDisplayName, objectProjectKey, canManageExposedElements, 'use', wt1Context);
-    }
-
-    this.requestSharing = function(objectType, objectId, objectDisplayName, projectKey, targetProject, wt1Context, actionVerb) {
-        if (!objectDisplayName) objectDisplayName = objectId;
-
-        return CreateModalFromTemplate("/templates/request-sharing-modal.html", $rootScope, "RequestSharingModalController", (newScope) => {
-            newScope.actionVerb = actionVerb || "use";
-            newScope.objectProjectKey = projectKey;
-            newScope.objectType = objectType;
-            newScope.objectDisplayName = objectDisplayName;
-            newScope.objectId = objectId;
-            const isInDataCatalog = $rootScope.$state.current.name === 'projects.project.datacatalog.datasources';
-            // when requesting to share an object from within a project, it does not make sense to target the current project ($stateParams.projectKey) 
-            // except from the catalog inside a project, where you have items that are not part of the current project 
-            const unusable = isInDataCatalog ? {[projectKey]: true} : {[projectKey]: true, [$stateParams.projectKey]: true}; 
-            newScope.ui = {unusable : unusable, requestMessage: "", sharingTargetProjectKey: targetProject};
-            newScope.wt1Context = wt1Context;
-        });
-    };
-
-    this.unshare = (deletionRequests, customMassDeleteSelected) => TaggableObjectsService.delete(deletionRequests, customMassDeleteSelected, true);
-
-    // API call & WT1 event for sharing an object.
-    // Does not handle errors, does not give visual feedback to the user
-    this.doExposeSingleObject = (objectType, objectProjectKey, objectId, targetProjectKey, objectDisplayName, isAlreadyQuickShared, showActivityIndicatorOnSuccess, wt1Context) => {
-        return DataikuAPI.projects
-            .addExposedObject(objectProjectKey, objectType, objectId, targetProjectKey, $stateParams.zoneId)
-            .success((data) => {
-                if(data.severity === 'SUCCESS') { // only send events if object was actually added
-                    this.sendWT1EventForDoExposeSingleObject(objectType, objectProjectKey, objectId, targetProjectKey, isAlreadyQuickShared, wt1Context)
-                }
-
-                // we always show the activity indicator when not in success
-                if (data.severity !== 'SUCCESS' || showActivityIndicatorOnSuccess) {
-                    const linkMessage = `View ${sanitize(objectDisplayName)} in flow`;
-                    const linkUrl = StateUtils.href.flowLinkFromProps(objectType, objectProjectKey, objectId, targetProjectKey);
-                    const message = `${data.title} <a href="${linkUrl}">${linkMessage}</a>.`;
-                    if (data.severity === 'SUCCESS') {
-                        ActivityIndicator.success(message, 5000);
-                    } else {
-                        ActivityIndicator.info(message, 5000);
-                    }
-                }
-            });
-    };
-
-    this.sendWT1EventForDoExposeSingleObject = (objectType, objectProjectKey, objectId, targetProjectKey, isAlreadyQuickShared, wt1Context) => {
-        const object = {
-            projectKey: objectProjectKey,
-            quickSharingEnabled: isAlreadyQuickShared,
-            type: objectType,
-            localName: objectId,
-            wt1Context
-        };
-        QuickSharingWT1EventsService.onRuleAdded(object, targetProjectKey);
-
-        // we need to get the current exposition to know if we just enabled sharing
-        if(!object.quickSharingEnabled) { // but since it cannot be the case if object was already quick-shared, skip the API call
-            DataikuAPI.projects.getObjectExposition(object.projectKey, object.type, object.localName).success((objectExposition) => {
-                if(objectExposition.rules.length === 1) {
-                    QuickSharingWT1EventsService.onSharingEnabled(object);
-                }
-            });
-        }
-    }
-
-});
 
 app.service('QuickSharingWT1EventsService', function(WT1) {
     const QUICK_SHARING = 'quick-sharing';
@@ -473,8 +384,9 @@ app.controller("ExposeObjectsModalController", function($scope, $stateParams, tr
         $scope.allTargetProjects[$stateParams.projectKey] = true;
     }
 
-    $scope.init = function(selectedItems) {
+    $scope.init = function(selectedItems, info) {
         $scope.selectedItems = selectedItems;
+        $scope.info = info;
         $scope.itemsType = TaggableObjectsUtils.getCommonType(selectedItems, it => it.type);
         QuickSharingWT1EventsService.onModalOpen('MULTIPLE');
 
