@@ -4,7 +4,7 @@
 var app = angular.module('dataiku.projects.actions');
 
 
-app.service('DatasetConnectionChangeService', function($rootScope, $q, $stateParams, $filter, CreateModalFromTemplate, DataikuAPI, TaggableObjectsCapabilities, TaggableObjectsUtils, Dialogs, SqlConnectionNamespaceService) {
+app.service('DatasetConnectionChangeService', function($rootScope, $q, $stateParams, $filter, CreateModalFromTemplate, DataikuAPI, TaggableObjectsCapabilities, TaggableObjectsUtils, Dialogs, SqlConnectionNamespaceService, ConnectionsService) {
     this.start = function(allSelectedObjects) {
 
         return CreateModalFromTemplate("/templates/datasets/change-connection-modal.html", $rootScope, null, function(modalScope) {
@@ -22,6 +22,8 @@ app.service('DatasetConnectionChangeService', function($rootScope, $q, $statePar
                 modalScope.modalTitle = `Change connection for "${name}"`
             }
 
+            modalScope.searchConnectionsWithDescriptions = ConnectionsService.searchConnectionsWithDescriptions;
+
             DataikuAPI.flow.refactoring.startChangeConnections($stateParams.projectKey, modalScope.selectedObjects).success(function(data) {
                 modalScope.connections = data.connections.filter(c => c.usable); //TODO @flow, display unsable connections with reason
 
@@ -78,6 +80,10 @@ app.service('DatasetConnectionChangeService', function($rootScope, $q, $statePar
                 SqlConnectionNamespaceService.listSqlCatalogs(connectionName, modalScope, 'change-connection-modal', modalScope.connectionsMap[modalScope.options.connection].type);
             }
 
+            modalScope.fetchNamespaces = function(connectionName) {
+                SqlConnectionNamespaceService.listIcebergNamespaces(connectionName, modalScope, 'change-connection-modal', modalScope.connectionsMap[modalScope.options.connection].type);
+            }
+
             modalScope.$watch("options.connection", function() {
                 if (modalScope.connectionsMap) {
                     SqlConnectionNamespaceService.setTooltips(modalScope, modalScope.connectionsMap[modalScope.options.connection].type);
@@ -128,6 +134,7 @@ app.service('SubFlowCopyService', function($rootScope, $q, $state, $stateParams,
                 el.type === 'SAVED_MODEL' ||
                 el.type === 'MODEL_EVALUATION_STORE'
                 || el.type === 'LABELING_TASK'
+                || el.type === 'RETRIEVABLE_KNOWLEDGE'
             );
 
             var copyDataTooltipHtml = `<div>
@@ -145,6 +152,7 @@ app.service('SubFlowCopyService', function($rootScope, $q, $state, $stateParams,
                                     <li>Saved models</li>
                                     <li>Model evaluation stores</li>
                                     <li>Labeling tasks</li>
+                                    <li>Knowledge banks</li>
                                 </ul>
                             </div>
 
