@@ -61,9 +61,13 @@ app.controller('OnboardingQuestionnaireController', function($scope, $location,
                 choices: [
                     { id: 'sales_marketing', label: 'Sales/Marketing', translationKey: 'ONBOARDING_QUESTIONNAIRE.SALES_MARKETING', freeField: false, fadeinAnimationSegment: [0, 48], fadeoutAnimationSegment: [48, 96]},
                     { id: 'manufacturing', label: 'Manufacturing', translationKey: 'ONBOARDING_QUESTIONNAIRE.MANUFACTURING', freeField: false, fadeinAnimationSegment: [96, 144], fadeoutAnimationSegment: [144, 192]},
-                    { id: 'supply_chain', label: 'Supply chain', translationKey: 'ONBOARDING_QUESTIONNAIRE.SUPPLY_CHAIN', freeField: false, fadeinAnimationSegment: [192, 240], fadeoutAnimationSegment: [240, 288]},
-                    { id: 'finance', label: 'Finance', translationKey: 'ONBOARDING_QUESTIONNAIRE.FINANCE', freeField: false, fadeinAnimationSegment: [288, 336], fadeoutAnimationSegment: [336, 384]},
-                    { id: 'other', label: 'Other', translationKey: 'ONBOARDING_QUESTIONNAIRE.OTHER', freeField: true, fadeinAnimationSegment: [384, 432], fadeoutAnimationSegment: [432, 480]},
+                    { id: 'finance', label: 'Finance', translationKey: 'ONBOARDING_QUESTIONNAIRE.FINANCE', freeField: false, fadeinAnimationSegment: [192, 240], fadeoutAnimationSegment: [240, 288]},
+                    { id: 'supply_chain', label: 'Supply chain & Procurement', translationKey: 'ONBOARDING_QUESTIONNAIRE.SUPPLY_CHAIN', freeField: false, fadeinAnimationSegment: [288, 336], fadeoutAnimationSegment: [336, 384]},
+                    { id: 'it', label: 'IT / Engineering / Data Analytics', translationKey: 'ONBOARDING_QUESTIONNAIRE.IT', freeField: false, fadeinAnimationSegment: [384, 432], fadeoutAnimationSegment: [432, 480]},
+                    { id: 'risk_compliance', label: 'Risk & Compliance', translationKey: 'ONBOARDING_QUESTIONNAIRE.RISK_COMPLIANCE', freeField: false, fadeinAnimationSegment: [480, 528], fadeoutAnimationSegment: [528, 576]},
+                    { id: 'operations', label: 'Operations', translationKey: 'ONBOARDING_QUESTIONNAIRE.OPERATIONS', freeField: false, fadeinAnimationSegment: [576, 624], fadeoutAnimationSegment: [624, 672]},
+                    { id: 'hr', label: 'HR', translationKey: 'ONBOARDING_QUESTIONNAIRE.HR', freeField: false, fadeinAnimationSegment: [672, 720], fadeoutAnimationSegment: [720, 768]},
+                    { id: 'other', label: 'Other', translationKey: 'ONBOARDING_QUESTIONNAIRE.OTHER', freeField: true, fadeinAnimationSegment: [768, 816], fadeoutAnimationSegment: [816, 864]},
                 ],
                 hasCategories: false,
             },
@@ -159,6 +163,22 @@ app.controller('OnboardingQuestionnaireController', function($scope, $location,
                 fadeoutAnimationSegment: [452, 504],
             });
         }
+
+        // Check that the user has a profile that allows basic LLM Mesh functionalities (writing project content is checked before)
+        if ($rootScope.appConfig.userProfile.mayBasicLLMMesh) {
+            paths.push({
+                id: "quick-start-gen-ai",
+                tutorialId: "QS_AGENTS",
+                opalsPage: OpalsService.PAGES.QUICKSTART_AGENTS,
+                icon: "dku-icon-llm-48",
+                title: "Use AI agents",
+                titleTranslationKey: "ONBOARDING_QUESTIONNAIRE.AI_AGENTS",
+                subtitle: "Learn how to leverage AI agents in Dataiku",
+                subtitleTranslationKey: "ONBOARDING_QUESTIONNAIRE.USE_AI_AGENTS",
+                fadeinAnimationSegment: [504, 616],
+                fadeoutAnimationSegment: [616, 670],
+            });
+        }
         
         $scope.recommendationStep = {
             template: '/templates/onboarding-questionnaire/recommendation.html',
@@ -585,31 +605,44 @@ app.controller('OnboardingQuestionnaireController', function($scope, $location,
         }
 
         $scope.showRecommendedBanner = function() {
-            return !$scope.onboardingState.skippedQuestionnaire && $scope.answers.experience.selection !== "gen_ai";
+            return !$scope.onboardingState.skippedQuestionnaire;
         }
 
         $scope.getQuickStartPaths = function() {
             // Order the list of quick start paths depending on user answers, since the paths are displayed by their position in the list
-            const experience = $scope.answers.experience;
-            if (experience.selection) {
-                const priorityOrder = {
-                    "data_preparation": "quick-start-data-preparation",
-                    "new": "quick-start-data-preparation",
-                    "ml": "quick-start-machine-learning",
-                    "gen_ai": ""
-                };
-        
-                // Sort paths based on the priority of the selected experience
+            const experienceSelection = $scope.answers.experience.selection;
+            const areaSelection = $scope.answers.area.selection;
+
+            const experienceToPathId = {
+                "data_preparation": "quick-start-data-preparation",
+                "new": "quick-start-data-preparation",
+                "ml": "quick-start-machine-learning",
+                "gen_ai": "quick-start-gen-ai"
+            };
+
+            let prioritizedPathId = null;
+            if (experienceSelection === "gen_ai") {
+                prioritizedPathId = experienceToPathId["gen_ai"];
+            } else if (areaSelection === "manufacturing") {
+                prioritizedPathId = experienceToPathId["data_preparation"];
+                // The data preparation path is updated in-place to open the manufacturing tutorial instead
+                const dataPrepPath = $scope.recommendationStep.paths.find(p => p.id === "quick-start-data-preparation");
+                dataPrepPath.opalsPage =  OpalsService.PAGES.QUICKSTART_MANUFACTURING_DATA_PREPARATION;
+                dataPrepPath.tutorialId = "QS_MANUF_DATA_PREP_VIZ";
+            } else if (experienceSelection && experienceToPathId[experienceSelection]) {
+                prioritizedPathId = experienceToPathId[experienceSelection];
+            }
+
+            if (prioritizedPathId) {
                 $scope.recommendationStep.paths.sort((a, b) => {
-                    // Check if either `a` or `b` matches the priority
-                    if (a.id === priorityOrder[experience.selection]) return -1;
-                    if (b.id === priorityOrder[experience.selection]) return 1;
-                    return 0; // Maintain order for other elements
+                    if (a.id === prioritizedPathId) return -1;
+                    if (b.id === prioritizedPathId) return 1;
+                    return 0;
                 });
             }
             return $scope.recommendationStep.paths;
         };
-        
+
         $scope.selectedQuickStartPath = null;
 
         $scope.selectQuickStartPath = function(path) {
