@@ -4,7 +4,7 @@
     angular.module('dataiku.charts')
         .factory('ScatterPlotChartDrawerWebGl', ScatterPlotChartDrawerWebGl);
 
-    function ScatterPlotChartDrawerWebGl(UaChartsCommon, ColorUtils, ChartDataUtils, ChartDimension, ChartColorUtils, ChartFeatures, ChartUADimension, D3ChartAxes, ReferenceLines, RegressionLine, ChartZoomControlAdapter, CHART_ZOOM_CONTROL_TYPES, CHART_TYPES, ChartAxesUtils, ChartUsableColumns, ChartsStaticData, ChartCustomMeasures, ScatterUtils, $timeout, ChartIconUtils, ConnectPointsSplitOptions, Logger) {
+    function ScatterPlotChartDrawerWebGl(UaChartsCommon, ColorUtils, ChartDataUtils, ChartDimension, ChartColorUtils, ChartFeatures, ChartUADimension, D3ChartAxes, ReferenceLines, RegressionLine, ChartZoomControlAdapter, CHART_ZOOM_CONTROL_TYPES, CHART_TYPES, ChartAxesUtils, ChartUsableColumns, ChartsStaticData, ChartCustomMeasures, ScatterUtils, $timeout, ChartIconUtils, ConnectPointsSplitOptions, Logger, ChartPropertiesService) {
         return function(container, chartDef, chartHandler, chartData, chartBase, uiDisplayState) {
             const g = d3.select(chartBase.$svgs.get(0));
             const multiple = chartDef.type === CHART_TYPES.SCATTER_MULTIPLE_PAIRS;
@@ -420,43 +420,41 @@
                 }
 
                 function onMouseMove(evt) {
-                    if (!chartHandler.noTooltips) {
-                        if (!isTooltipsReady()) {
-                            return;
-                        }
-                        if (ChartZoomControlAdapter.isZooming(chartDef.$zoomControlInstanceId) || ChartZoomControlAdapter.isBrushing(chartDef.$zoomControlInstanceId)) {
-                            hideTooltip();
-                        } else {
-                            const rect = evt.target.getBoundingClientRect();
-                            const mousePos = getMousePos(rect, evt);
-                            const bests = [];
-                            series.forEach((serie, serieIdx) => {
-                                const serieXscale = serie.xScale();
-                                const serieYscale = serie.yScale();
-                                // From x,y on screen get x,y in on the domain
-                                const x = getValueForMousePos(chartBase.xAxis, serieXscale, mousePos.x, multiple ? chartData.data.axesPairs[serieIdx].xAxis : chartData.data.xAxis);
-                                const y = getValueForMousePos(chartBase.yAxes[serieIdx], serieYscale, mousePos.y, multiple ? chartData.data.axesPairs[serieIdx].yAxis : chartData.data.yAxis);
-                                if (x !== -1 && y !== -1) {
-                                    // Add some radius in domain values so we have margins to select in the spatial index
-                                    const radiusX = getRadiusInDomainFromMousePos(chartBase.xAxis, x, serieXscale, mousePos.x);
-                                    const radiusY = getRadiusInDomainFromMousePos(chartBase.yAxes[serieIdx], y, serieYscale, mousePos.y);
-                                    bests.push(kdbushs[serieIdx].range(x - radiusX, y - radiusY, x + radiusX, y + radiusY));
-                                }
-                            });
-                            if (bests.some(best => best.length)) {
-                                const pairIndex = bests.findIndex(best => best.length);
-                                const i = bests[pairIndex][0];
-                                const color = getColorForSerie(pairIndex)(i);
-                                chartBase.tooltips.showForCoords(0, { x: i, y: i, color: i, extras: { shape: i, size: i, pair: pairIndex } }, { pageX: mousePos.x + rect.left, pageY: mousePos.y + rect.top, target: canvas }, color);
-
-                                updateTooltipHighlightSerie(pairIndex, i);
-                                tooltipHighlight = true;
-                                redrawTooltipHighlight();
-                            } else {
-                                hideTooltip();
-                            }
-                        }
+                    if (!isTooltipsReady() || !ChartPropertiesService.showTooltip(chartDef.tooltipOptions, chartHandler.chartTileProperties)) {
+                        return;
                     }
+                    if (ChartZoomControlAdapter.isZooming(chartDef.$zoomControlInstanceId) || ChartZoomControlAdapter.isBrushing(chartDef.$zoomControlInstanceId)) {
+                        hideTooltip();
+                    } else {
+                        const rect = evt.target.getBoundingClientRect();
+                        const mousePos = getMousePos(rect, evt);
+                        const bests = [];
+                        series.forEach((serie, serieIdx) => {
+                            const serieXscale = serie.xScale();
+                            const serieYscale = serie.yScale();
+                            // From x,y on screen get x,y in on the domain
+                            const x = getValueForMousePos(chartBase.xAxis, serieXscale, mousePos.x, multiple ? chartData.data.axesPairs[serieIdx].xAxis : chartData.data.xAxis);
+                            const y = getValueForMousePos(chartBase.yAxes[serieIdx], serieYscale, mousePos.y, multiple ? chartData.data.axesPairs[serieIdx].yAxis : chartData.data.yAxis);
+                            if (x !== -1 && y !== -1) {
+                                // Add some radius in domain values so we have margins to select in the spatial index
+                                const radiusX = getRadiusInDomainFromMousePos(chartBase.xAxis, x, serieXscale, mousePos.x);
+                                const radiusY = getRadiusInDomainFromMousePos(chartBase.yAxes[serieIdx], y, serieYscale, mousePos.y);
+                                bests.push(kdbushs[serieIdx].range(x - radiusX, y - radiusY, x + radiusX, y + radiusY));
+                            }
+                        });
+                        if (bests.some(best => best.length)) {
+                            const pairIndex = bests.findIndex(best => best.length);
+                            const i = bests[pairIndex][0];
+                            const color = getColorForSerie(pairIndex)(i);
+                            chartBase.tooltips.showForCoords(0, { x: i, y: i, color: i, extras: { shape: i, size: i, pair: pairIndex } }, { pageX: mousePos.x + rect.left, pageY: mousePos.y + rect.top, target: canvas }, color);
+
+                            updateTooltipHighlightSerie(pairIndex, i);
+                            tooltipHighlight = true;
+                            redrawTooltipHighlight();
+                        } else {
+                            hideTooltip();
+                        }
+                    };
                 }
 
                 function onMouseUp() {
