@@ -6,10 +6,11 @@
 
     /** @typedef {import('../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community').GridOptions} GridOptions */
     /** @typedef {import('../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community')} AgGrid */
+    /** @typedef {import('../../../../../../../../../../server/src/frontend/src/app/migration/services/ag-grid-loader.service').AgGridLoaderService} AgGridLoader */
 
     const app = angular.module('dataiku.charts');
     // (!) This service previously was in static/dataiku/js/simple_report/table/pivot_table.js
-    app.factory('PivotTableChart', function(ChartFormatting, ChartDataWrapperFactory, ChartTooltips, ChartCustomMeasures, ChartContextualMenu, ChartStoreFactory, ChartUsableColumns, ColumnAvailability, /** @type {AgGrid} */ AgGrid, AgGridConverter, HierarchicalChartsUtils, PivotTableUtils, ChartFormattingPaneSections) {
+    app.factory('PivotTableChart', function(ChartFormatting, ChartDataWrapperFactory, ChartTooltips, ChartCustomMeasures, ChartContextualMenu, ChartStoreFactory, ChartUsableColumns, ColumnAvailability, /** @type {AgGridLoader} */ AgGridLoader, AgGridConverter, ChartDrilldown, PivotTableUtils, ChartFormattingPaneSections, ChartDimension, ChartHierarchyDimension) {
         /** @type JQuery<HTMLElement> */
         let $rootElement;
         /** @type JQuery<HTMLElement> */
@@ -18,9 +19,12 @@
         let lastAxesDefDisplayed;
         const MEASURE_COLUMN_KEY = '__MEASURE__LIST__';
         let contextualMenu;
-        let defaulTopHeadersMenuListener;
+        let defaultTopHeadersMenuListener;
+        let defaultBackgroundMenuListener;
         let topRowHeadersMenuListener;
         let instanceChartHandler;
+        /** @type {AgGrid} */
+        let AgGrid; // Will be set when AgGridLoader loads the library
         /**
          * Initializes the DOM Element that will be used as a container for the pivot table.
          *
@@ -89,14 +93,25 @@
                 gridApi.setColumnsVisible([store.getDimensionId(dimension)], show);
             });
 
+            const yHierarchyDimension = ChartHierarchyDimension.getCurrentHierarchyDimension(chartDef, 'y');
+            if (yHierarchyDimension) {
+                gridApi.setColumnVisible(store.getDimensionId(yHierarchyDimension), show);
+            }
+
             gridApi.setColumnsVisible([MEASURE_COLUMN_KEY], show);
         }
 
         function showRowMainHeaderContextualMenu(event, cellValue, chartDef, mainHeader) {
             const rowHeadersCallbacks = PivotTableUtils.getToggleRowHeadersCallbacks(chartDef, instanceChartHandler.openSection);
-            const actions = PivotTableUtils.getRowHeaderContextualMenuActions(chartDef.pivotTableOptions.tableFormatting, chartDef.yDimension.length <= 1, rowHeadersCallbacks, cellValue, mainHeader);
+            const actions = PivotTableUtils.getRowHeaderContextualMenuActions(chartDef, rowHeadersCallbacks, cellValue, mainHeader);
             event.preventDefault();
-            contextualMenu.open(event, undefined, actions, 'pivotTableHeader');
+            contextualMenu.open({ event, customActions: actions, type: 'pivotTableHeader' });
+        }
+
+        function showBackgroundContextualMenu(event, chartDef) {
+            const actions = ChartDrilldown.getDrillupActions(chartDef);
+            event.preventDefault();
+            contextualMenu.open({ event, customActions: actions, type: 'background' });
         }
 
         function showColumnHeaderContextualMenu(event, cellValue, chartDef, mainHeader) {
@@ -106,7 +121,7 @@
                     instanceChartHandler.openSection(ChartFormattingPaneSections.TABLE);
                 }
             };
-            contextualMenu.open(event, undefined, PivotTableUtils.getColumnHeaderActions(chartDef.pivotTableOptions.tableFormatting, cellValue, mainHeader, columnHeadersCallbacks), 'pivotTableHeader' );
+            contextualMenu.open({ event, customActions: PivotTableUtils.getColumnHeaderActions(chartDef, cellValue, mainHeader, columnHeadersCallbacks), type: 'pivotTableHeader' });
         }
 
         function updateTopHeadersContextualMenuListeners(chartDef) {
@@ -114,12 +129,17 @@
             addTopHeadersContextualMenuListeners(chartDef);
         }
 
+        function updateBackgroundContextualMenuListener(chartDef) {
+            removeBackgroundContextualMenuListener();
+            addBackgroundContextualMenuListener(chartDef);
+        }
+
         function removeTopHeadersContextualMenuListeners() {
             const defaulTopHeaders = $container[0].querySelector('.ag-header-viewport');
             const topRowHeaders = $container[0].querySelector('.ag-pinned-left-header');
 
             if (defaulTopHeaders) {
-                defaulTopHeaders.removeEventListener('contextmenu', defaulTopHeadersMenuListener);
+                defaulTopHeaders.removeEventListener('contextmenu', defaultTopHeadersMenuListener);
             }
 
             if (topRowHeaders) {
@@ -127,6 +147,14 @@
             }
         }
 
+        function removeBackgroundContextualMenuListener() {
+            const gridBody = $container[0].querySelector('.ag-body');
+
+            if (gridBody) {
+                gridBody.removeEventListener('contextmenu', defaultBackgroundMenuListener);
+            }
+        }
+
         /*
          * Row subheaders not part of agGrid top headers. They are simple cells built with custom renderer, not accessible right away after init like the top header.
          * Consequently, their contextual menu listeners are built in the converter service and must be removed when destroying the pivot.
@@ -156,7 +184,7 @@
                 rowHeaders.addEventListener('contextmenu', topRowHeadersMenuListener);
             }
 
-            defaulTopHeadersMenuListener = (event) => {
+            defaultTopHeadersMenuListener = (event) => {
                 const rowMainHeader = event.target.closest('.' + PivotTableUtils.ROW_MAIN_HEADER_CLASSNAME) || event.target.querySelector('.' + PivotTableUtils.ROW_MAIN_HEADER_CLASSNAME);
                 const columnMainHeader = event.target.closest('.' + PivotTableUtils.COLUMN_MAIN_HEADER_CLASSNAME) || event.target.querySelector('.' + PivotTableUtils.COLUMN_MAIN_HEADER_CLASSNAME);
                 const columnSubheader = event.target.closest('.' + PivotTableUtils.COLUMN_SUBHEADER_CLASSNAME) || event.target.querySelector('.' + PivotTableUtils.COLUMN_SUBHEADER_CLASSNAME);
@@ -170,7 +198,24 @@
                 }
             };
 
-            defaulTopHeaders.addEventListener('contextmenu', defaulTopHeadersMenuListener);
+            defaulTopHeaders.addEventListener('contextmenu', defaultTopHeadersMenuListener);
+        }
+
+        function addBackgroundContextualMenuListener(chartDef) {
+            const xHierarchyLevel = ChartHierarchyDimension.getCurrentHierarchyLevel(chartDef, 'x');
+            const yHierarchyLevel = ChartHierarchyDimension.getCurrentHierarchyLevel(chartDef, 'y');
+            if (xHierarchyLevel > 0 || yHierarchyLevel > 0) {
+                const gridBody = $container[0].querySelector('.ag-body');
+                defaultBackgroundMenuListener = (event) => {
+                    const isBackgroundClick = (event.target.closest('.ag-body') || event.target.querySelector('.ag-body'))
+                        && !event.target.closest('.ag-center-cols-container');
+                    if (isBackgroundClick) {
+                        showBackgroundContextualMenu(event, chartDef);
+                    };
+                };
+
+                gridBody.addEventListener('contextmenu', defaultBackgroundMenuListener);
+            }
         }
 
         /**
@@ -186,6 +231,7 @@
             updateColumnVisibilities(gridApi, chartDef, store);
             chartDef.pivotTableOptions.showSidebar ? gridApi.setSideBarVisible(true): gridApi.setSideBarVisible(false);
             addTopHeadersContextualMenuListeners(chartDef);
+            addBackgroundContextualMenuListener(chartDef);
         }
 
         /**
@@ -200,6 +246,7 @@
 
             removeRowSubheadersContextualMenuListeners();
             updateTopHeadersContextualMenuListeners(chartDef);
+            updateBackgroundContextualMenuListener(chartDef);
 
             const { sideBar, columnDefs, ...newGridOptionsWithoutColumnDefsAndSideBar } = newGridOptions;
             if (chartDef.pivotTableOptions.showSidebar && typeof newGridOptions.sideBar !== 'string' && typeof newGridOptions.sideBar !== 'boolean') {
@@ -274,6 +321,7 @@
             if ($container && $container[0]) {
                 removeTopHeadersContextualMenuListeners();
                 removeRowSubheadersContextualMenuListeners();
+                removeBackgroundContextualMenuListener();
             }
 
             if (gridApi != null && gridApi.destroy) {
@@ -315,11 +363,11 @@
          * @param {PivotTableTensorResponse} data
          * @param {DataVisualizationTheme} theme
          */
-        return function PivotTableChart($element, chartDef, chartHandler, axesDef, data) {
+        function PivotTableChart($element, chartDef, chartHandler, axesDef, data) {
 
             const { store, id } = ChartStoreFactory.getOrCreate(chartDef.$chartStoreId);
             chartDef.$chartStoreId = id;
-            HierarchicalChartsUtils.updateChartStoreMeasureIDsAndDimensionIDs(store, chartDef);
+            store.updateChartStoreMeasureIDsAndDimensionIDs(chartDef);
             instanceChartHandler = chartHandler;
 
             const dataSpec = chartHandler.getDataSpec();
@@ -360,5 +408,11 @@
                 purgeAgGrid(chartDef);
             });
         };
+
+        return ($element, chartDef, chartHandler, axesDef, data, theme) => {
+            AgGridLoader.load()
+                .then(loaded => AgGrid = loaded)
+                .then(() => PivotTableChart($element, chartDef, chartHandler, axesDef, data, theme));
+        };
     });
 })();
