@@ -8,7 +8,7 @@
     /**
      * (!) This service previously was in static/dataiku/js/simple_report/common/tooltips.js
      */
-    function ChartTooltips($q, $templateCache, $http, $compile, $rootScope, ChartFilters, ChartFormatting, ChartColorScales, ChartLabels, ChartDimension, ChartColorUtils, AnimatedChartsUtils, CHART_TYPES, ChartStoreFactory, ChartFeatures, Logger, ChartUADimension, $stateParams, DKU_OTHERS_VALUE, DashboardFilters, DashboardUtils, HierarchicalChartsUtils, ConditionalFormattingOptions, ChartDrilldown, ChartHierarchyDimension, DKU_TOTAL_VALUE, DRILL_UP_SOURCE, DRILL_DOWN_SOURCE) {
+    function ChartTooltips($templateRequest, $compile, $rootScope, ChartFilters, ChartFormatting, ChartColorScales, ChartLabels, ChartDimension, ChartColorUtils, AnimatedChartsUtils, CHART_TYPES, ChartStoreFactory, ChartFeatures, Logger, ChartUADimension, $stateParams, DKU_OTHERS_VALUE, DashboardFilters, DashboardUtils, HierarchicalChartsUtils, ConditionalFormattingOptions, ChartDrilldown, ChartHierarchyDimension, DKU_TOTAL_VALUE, DRILL_UP_SOURCE, DRILL_DOWN_SOURCE, ChartPropertiesService) {
         const DASHBOARD_TOOLTIPS_CONTAINER_SELECTOR = '.dashboard-tile__chart-tooltips-container';
         const DASHBOARD_TOOLTIP_CONTAINER_CLASS = 'dashboard-tile__chart-tooltip-container';
         const DASHBOARD_TOOLTIP_CONTAINER_SELECTOR = `.${DASHBOARD_TOOLTIP_CONTAINER_CLASS}`;
@@ -415,7 +415,7 @@
 
                     const dimensionTooltipId = `qa_charts_tooltip-dimension-${(dimension.column || '').replace(/\s/g, '_')}`;
 
-                    let value, filterValue;
+                    let value, filterValue, isTotalBin;
 
                     if (chartDef.type === CHART_TYPES.SCATTER || chartDef.type === CHART_TYPES.SCATTER_MULTIPLE_PAIRS) {
                         label = ChartLabels.getUaLabel(dimension);
@@ -453,7 +453,9 @@
                         axisElt = dimension;
                         dimension = radarDimension;
                     } else {
-                        axisElt = chartData.getAxisLabels(axisName)[coords[axisName]];
+                        const finalCoord = coords.tooltipOverrides?.[axisName] ?? coords[axisName];
+                        axisElt = chartData.getAxisLabels(axisName)[finalCoord];
+                        isTotalBin = chartData.isComputedTotal?.(axisName, coords);
                         value = ChartLabels.getAxisEltFormattedLabel({
                             chartDef,
                             chartData,
@@ -469,12 +471,11 @@
                     const isRadarChartMeasure = chartDef.type === CHART_TYPES.RADAR && axisElt.isA === 'measure';
                     const isInReusableDimensionPreview = chartDef.$isInReusableDimensionPreview;
                     const isOthersBin = axisElt.label === DKU_OTHERS_VALUE;
-                    const isTotalBar = axisElt.label === DKU_TOTAL_VALUE;
                     const canAddEmptyFilter = canChartTypeBeFiltered && !isRadarChartMeasure && !isInReusableDimensionPreview;
-                    const canFilter = canChartTypeBeFiltered && !isRadarChartMeasure && !isOthersBin && !isTotalBar && (!isInDashboard || DashboardFilters.canCrossFilter($stateParams.pageId)) && !isInReusableDimensionPreview;
-                    const isDrillable = canFilter && !isInDashboard && ChartDimension.isDrillable(dimension);
+                    const canFilter = canChartTypeBeFiltered && !isRadarChartMeasure && !isOthersBin && !isTotalBin && (!isInDashboard || DashboardFilters.canCrossFilter($stateParams.pageId)) && !isInReusableDimensionPreview;
+                    const isDrillable = canFilter && !isInDashboard && ChartDimension.isDrillableForElement(chartDef, dimension, axisElt);
                     const nativeDrilldownType = isDrillable ? ChartDimension.isGroupedNumerical(dimension) ? 'NUMERICAL' : 'DATE' : null;
-                    const isHierarchyDrillable = dimension && !isTotalBar && ChartFeatures.canDrillHierarchy(chartDef.type) && dimension.hierarchyId && !isOthersBin && !isRadarChartMeasure;
+                    const isHierarchyDrillable = dimension && !isTotalBin && ChartFeatures.canDrillHierarchy(chartDef.type) && dimension.hierarchyId && !isOthersBin && !isRadarChartMeasure;
                     const isHierarchyDrillableDown = isHierarchyDrillable && ChartHierarchyDimension.canDimensionDrillDown(chartDef, dimension);
                     const isHierarchyDrillableUp = isHierarchyDrillable && ChartHierarchyDimension.canDimensionDrillUp(chartDef, dimension);
                     const hierarchyName = !isRadarChartMeasure && ChartHierarchyDimension.getDimensionHierarchyName(chartDef, dimension);
@@ -504,7 +505,7 @@
                         canAddEmptyFilter,
                         isOthersBin,
                         chartTheme,
-                        isTotalBar,
+                        isTotalBin,
                         addEmptyFilter: () => {
                             const newFilter = ChartFilters.createFilter({ column: dimension.column, columnType: dimension.type, excludeOtherValues: false });
                             chartDef.filters = ChartFilters.updateOrAddFilter(chartDef.filters, newFilter);
@@ -545,7 +546,7 @@
                         { isDisplayed: !!chartDef.uaShape[0] && hasUaDimensions(chartDef), dimension: chartDef.uaShape[0], axisName: 'shape' },
                         { isDisplayed: !!chartDef.uaSize[0] && hasUaDimensions(chartDef), dimension: chartDef.uaSize[0], axisName: 'size' },
                         {
-                            isDisplayed: chartDef.genericDimension0.length && ![CHART_TYPES.PIE, CHART_TYPES.RADAR, CHART_TYPES.SANKEY].includes(chartDef.type),
+                            isDisplayed: chartDef.genericDimension0.length && ![CHART_TYPES.PIE, CHART_TYPES.RADAR, CHART_TYPES.GAUGE, CHART_TYPES.SANKEY].includes(chartDef.type),
                             dimension: chartDef.genericDimension0[0],
                             axisName: chartDef.type === CHART_TYPES.STACKED_BARS ? 'y' : 'x'
                         },
@@ -667,7 +668,7 @@
                 const defaultTooltipState = { shown: false, formatters: measureFormatters, canPinTooltip: ChartFeatures.canPinTooltip(chartDef.type) };
                 const templateUrl = '/templates/simple_report/tooltips/std-aggr-nd.html';
 
-                $q.when($templateCache.get(templateUrl) || $http.get(templateUrl, { cache: true })).then(function(template) {
+                $templateRequest(templateUrl).then(function(template) {
                     if (angular.isArray(template)) {
                         template = template[1];
                     } else if (angular.isObject(template)) {
@@ -696,7 +697,7 @@
                      */
                     showForCoords: function(measure, coords, event, color, options) {
 
-                        if (!ChartFeatures.shouldDisplayTooltips(chartHandler.noTooltips, chartDef.tooltipOptions, ret.fixed)) {
+                        if (!ChartPropertiesService.showTooltip(chartDef.tooltipOptions, chartHandler.chartTileProperties, ret.fixed)) {
                             return;
                         }
 
@@ -713,7 +714,7 @@
                             tooltipScope.shown = true;
                             const canPinTooltip = ChartFeatures.canPinTooltip(chartDef.type);
                             tooltipScope.dimensionEntries = getDimensionEntries(coords ? { ...coords, facet: facetIndex } : undefined, options);
-                            const canDisplayTooltipMeasures = tooltipScope.dimensionEntries.every(entry => !entry.isTotalBar);
+                            const canDisplayTooltipMeasures = tooltipScope.dimensionEntries.every(entry => !entry.isTotalBin);
                             tooltipScope.additionalMeasures = options && options.additionalMeasures !== null ? options.additionalMeasures : [];
                             const hasFilterableAxisElts = tooltipScope.dimensionEntries.some(entry => entry.canFilter);
                             tooltipScope.canMultiDimensionalFilter = tooltipScope.dimensionEntries.every(entry => entry.canFilter);
@@ -849,7 +850,7 @@
                      * Fix the tooltip (won't follow mouse anymore and won't auto-hide)
                      */
                     fix: function() {
-                        if (!ChartFeatures.shouldDisplayTooltips(chartHandler.noTooltips, chartDef.tooltipOptions, false)) {
+                        if (!ChartPropertiesService.showTooltip(chartDef.tooltipOptions, chartHandler.chartTileProperties)) {
                             return;
                         }
                         if (ret.fixed) {
@@ -966,7 +967,7 @@
                         element
                             .on('mouseover', () => ret.handleChartMouseOver(getTargetElementProperties, colorFocusHandler))
                             .on('mouseout', () => ret.handleChartMouseOut(getTargetElementProperties, colorFocusHandler));
-                        if (!chartHandler.noTooltips) {
+                        if (!chartHandler.chartTileProperties || chartHandler.chartTileProperties.showTooltips) {
                             element
                                 .on('mousemove', () => ret.handleChartMouseMove(getTargetElementProperties, colorFocusHandler, tooltipOptions))
                                 .on('click', () => ret.handleChartClick(getTargetElementProperties))
@@ -1004,7 +1005,7 @@
                      * @param {boolean} noTooltip: only register the element for color change but don't add tooltip handlers
                      */
                     registerEl: function(el, coords, colorAttr, noTooltip, options, hasColorDim = false) {
-                        if (chartHandler.noTooltips) {
+                        if (chartHandler.chartTileProperties && !chartHandler.chartTileProperties.showTooltips) {
                             return;
                         }
 
@@ -1068,7 +1069,7 @@
                      * @param color
                      */
                     addTooltipHandlers: function(el, coords, color) {
-                        if (chartHandler.noTooltips) {
+                        if (chartHandler.chartTileProperties && !chartHandler.chartTileProperties.showTooltips) {
                             return;
                         }
 
