@@ -21,8 +21,10 @@ const TAGGABLE_TYPES = [
     'MODEL_EVALUATION_STORE',
     'MODEL_COMPARISON',
     'PROMPT_STUDIO',
+    'SEMANTIC_MODEL',
     'RETRIEVABLE_KNOWLEDGE',
     'AGENT_TOOL',
+    'AGENT_REVIEW',
     'SCENARIO',
     'DASHBOARD',
     'INSIGHT',
@@ -32,7 +34,9 @@ const TAGGABLE_TYPES = [
     'ARTICLE',
     'LAMBDA_SERVICE',
     'WORKSPACE',
-    'DATA_COLLECTION'
+    'DATA_COLLECTION',
+    'ENTERPRISE_ASSET_COLLECTION',
+    'ENTERPRISE_ASSET',
 ];
 
 app.constant("TAGGABLE_TYPES", TAGGABLE_TYPES);
@@ -126,6 +130,29 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
         return commonType || 'TAGGABLE_OBJECT';
     };
 
+    this.getCommonIndexableType = function(items, typeFieldAccessor) {
+        const types = new Set(items.map(item => typeFieldAccessor?.(item) ?? item));
+        return types.size === 1 ? types.values().next().value : 'INDEXABLE_OBJECT';
+    };
+
+    this.getIndexableTypeFromNode = function(node, nodeType) {
+        const taggableType = this.fromNodeType(nodeType);
+        if (taggableType === 'SAVED_MODEL' && node.savedModelType) {
+            switch (node.savedModelType) {
+                case 'PYTHON_AGENT':
+                case 'PLUGIN_AGENT':
+                case 'TOOLS_USING_AGENT':
+                    return 'AI_AGENT';
+                case 'LLM_GENERIC':
+                case 'RETRIEVAL_AUGMENTED_LLM':
+                    return 'GEN_AI_MODEL';
+                default:
+                    break;
+            }
+        }
+        return taggableType;
+    }
+
     this.fromNodeType = function(nodeType) {
         if (!nodeType) return;
 
@@ -147,8 +174,12 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return 'GENAI_COMPARISON';
         } else if (nodeType.includes('PROMPT_STUDIO')) {
             return 'PROMPT_STUDIO';
+        } else if (nodeType.includes('SEMANTIC_MODEL')) {
+            return 'SEMANTIC_MODEL';
         } else if (nodeType.includes('AGENT_TOOL')) {
             return 'AGENT_TOOL';
+        } else if (nodeType.includes('AGENT_REVIEW')) {
+            return 'AGENT_REVIEW';
         } else if (nodeType.includes('STREAMING_ENDPOINT')) {
             return 'STREAMING_ENDPOINT';
         } else if (nodeType.includes('MANAGED_FOLDER')) {
@@ -263,8 +294,12 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
             return 'SAVED_MODEL';
         } else if (stateName.startsWith('projects.project.promptstudios')) {
             return 'PROMPT_STUDIO';
+        } else if (stateName.startsWith('projects.project.semanticmodels')) {
+            return 'SEMANTIC_MODEL';
         } else if (stateName.startsWith('projects.project.agenttools')) {
             return 'AGENT_TOOL';
+        } else if (stateName.startsWith('projects.project.agentreviews')) {
+            return 'AGENT_REVIEW';
         } else if (stateName.startsWith('projects.project.recipes')) {
             return 'RECIPE';
         } else if (stateName.startsWith('projects.project.analyses')) {
@@ -323,6 +358,7 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
 });
 
 
+// TODO : Candidate for Angular migration
 app.service("TaggableObjectsService", function($stateParams, $rootScope, $q, DataikuAPI, CreateModalFromTemplate, Dialogs, Logger, QuickSharingWT1EventsService) {
     const THUMBNAIL_WIDTH = 220;
     const THUMBNAIL_HEIGHT = 138;
@@ -577,8 +613,12 @@ app.filter('niceTaggableType', function($filter, $translate) {
         'SQL_NOTEBOOK': 'SQL notebook',
         'SEARCH_NOTEBOOK': 'Search notebook',
         'RETRIEVABLE_KNOWLEDGE': 'knowledge bank',
-        'TAGGABLE_OBJECT': 'item'
-    };
+        'TAGGABLE_OBJECT': 'item',
+        'INDEXABLE_OBJECT': 'item',
+        'GEN_AI_MODEL': 'GenAI model',
+        "AI_AGENT": 'AI agent'
+
+        };
     const plurals = {
         'ANALYSIS': 'analyses'
     };
@@ -1067,9 +1107,8 @@ app.controller('_TaggableObjectsCapabilities', function($scope, TaggableObjectsC
 
 app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScope, $q, $stateParams, WT1, Logger, Dialogs, DataikuAPI, CreateModalFromTemplate,
     TaggableObjectsService, TaggingService, translate,
-    ImpalaService, HiveService, SparkService, ComputablesService, DatasetsService, DatasetConnectionChangeService, SubFlowCopyService, RecipesEnginesService, ExposedObjectsService,
-    GlobalProjectActions, RecipeDescService, FlowGraphSelection, FlowTool,
-    InterestsService, InterestWording, WatchInterestState, TaggableObjectsUtils,
+    ImpalaService, HiveService, SparkService, ComputablesService, DatasetsService, DatasetConnectionChangeService, RecipesEnginesService, Ng2ObjectsExpositionService,
+    GlobalProjectActions, InterestsService, InterestWording, WatchInterestState,
     CodeEnvsService, ToolBridgeService, PipelineService, PIPELINEABILITY_ACTIONS) {
     //Expects a $scope.getSelectedTaggableObjectRefs()
 
@@ -1196,7 +1235,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
 
     $scope.exposeSelected = function() {
         WT1.event("action-share", {state: $state.current.name, items: $scope.getSelectedTaggableObjectRefs().length});
-        ExposedObjectsService.exposeObjects($scope.getSelectedTaggableObjectRefs()).then(onAction('action-share'));
+        Ng2ObjectsExpositionService.exposeObjects($scope.getSelectedTaggableObjectRefs()).then(onAction('action-share'));
     };
 
     $scope.unshare = function() {
@@ -1204,7 +1243,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
         var items = $scope.getSelectedTaggableObjectRefs();
         var deletionRequests = items.map(item => ({type: item.type, projectKey: item.projectKey, id: item.id, displayName: item.displayName}))
 
-        ExposedObjectsService.unshare(deletionRequests).then(onAction('action-unshare'));
+        Ng2ObjectsExpositionService.unshare(deletionRequests).then(onAction('action-unshare'));
     };
 
     $scope.isZoneInput = function() {
@@ -2007,6 +2046,7 @@ app.directive('customFieldsInSidePanel', function($rootScope, Logger, PluginConf
             saveFn: '=',
             editCustomFields: '=',
             editable: '=',
+            rightPanelTabName: '=',
         },
         link : function($scope, element, attrs) {
             $scope.customFieldsMap = $rootScope.appConfig.customFieldsMap[$scope.objectType];
@@ -2039,6 +2079,11 @@ app.directive('customFieldsInSidePanel', function($rootScope, Logger, PluginConf
                     $scope.saveFn(angular.copy($scope.ui.customFields));
                 }
             };
+
+            $scope.tabLabelFilterFn = function(value, index, array) {
+                return $scope.rightPanelTabName === undefined || (value && value.rightPanelTabName === $scope.rightPanelTabName);
+            };
+
             $scope.$watch('customFields', function() {
                 $scope.ui.customFields = angular.copy($scope.customFields);
                 PluginConfigUtils.setDefaultValues(customFieldsMapFlattenList, $scope.ui.customFields);
