@@ -86,6 +86,12 @@ app.controller('ProfileController', function($scope, $state, $stateParams, $root
         $scope.oldUserSettings = angular.copy($scope.userSettings);
     };
 
+    $scope.toggleAutoStackUp = function () {
+        WT1.event('dashboard-auto-stack-up-toggled-from-user-settings', {
+            autoStackUp: $scope.userSettings.dashboards.autoStackUp
+        });
+    };
+
     $scope.sampleMessengerNotification = function () {
         MessengerUtils.post({
           message: translate("PROFILE.MY_SETTINGS.NOTIFICATIONS.SAMPLE", "Here is your example! <br/> So, what do you want to be notified of?"),
@@ -673,7 +679,7 @@ app.directive('achievements', function(AchievementService, Notification, Logger,
     return {
         restrict : 'A',
         link : function($scope, element, attrs) {
-            Notification.registerEvent("achievement-unlocked", function(evt, message) {
+            const achievementUnlockedUnsubscribe = Notification.registerEvent("achievement-unlocked", function(evt, message) {
                 Logger.info("Achievement unlocked", message);
 
                 $http.get(templatePath, {cache: $templateCache}).then(function(response) {
@@ -693,6 +699,7 @@ app.directive('achievements', function(AchievementService, Notification, Logger,
                     window.setTimeout(function() {a.addClass("gone");}, 5000);
                 });
             });
+            $scope.$on('$destroy', achievementUnlockedUnsubscribe);
         }
     };
 });
@@ -790,4 +797,64 @@ app.service('UserSettingsService', function (DataikuAPI, $rootScope, WT1, Activi
 
 });
 
+    app.component('userSettingsPageSectionForm', {
+        templateUrl: '/templates/profile/page-section-form.html',
+        bindings: {
+            pageSectionSettings: '<',
+        },
+        controller: function (DashboardPageSectionFormatService, $scope, translate, $timeout) {
+            const ctrl = this;
+
+            ctrl.pageSectionFormats = [
+                { id: 'FIT_TO_PAGE', label: translate(`DASHBOARD_SETTINGS.ZOOM_MODE.FORM.FIXED_ASPECT_RATIO.LABEL`, 'Fixed aspect ratio') },
+                { id: 'FIT_TO_WIDTH', label: translate(`DASHBOARD_SETTINGS.ZOOM_MODE.FORM.FIT_TO_WIDTH.LABEL`, 'Fit to width') },
+            ];
+
+            // The Settings page is considered "modified" if its JSON differs from the original JSON.
+            // Therefore, we need to reuse the initial pageSectionFormat if it matches the one selected in the frontend 
+            // (the frontend’s pageSectionFormat is slightly different from the backend’s).
+            // Ideally, the “modified” state of the Settings page should have been more granular than a simple JSON comparison.
+            ctrl.initialPageSectionFormatInput = null;
+
+            $scope.$watch('$ctrl.pageSectionSettings.pageSectionFormat', (newPageSectionFormat) => {
+                if (newPageSectionFormat == undefined) {
+                    return;
+                }
+
+                if (ctrl.initialPageSectionFormatInput == null) {
+                    ctrl.initialPageSectionFormatInput = DashboardPageSectionFormatService.createPageSectionFormat({
+                        ...newPageSectionFormat,
+                    });
+                }
+            });
+
+            ctrl.onPageSectionFormatUpdated = ($event) => {
+
+                const formatUpdated = ctrl.initialPageSectionFormatInput.formatName !== $event.formatName;
+                const orientationUpdated = ctrl.initialPageSectionFormatInput.orientation !== $event.orientation;
+                const customSizeUpdated = (
+                    !formatUpdated
+                    && $event.formatName === 'CUSTOM'
+                    && (
+                        ctrl.initialPageSectionFormatInput.xInPx !== $event.xInPx
+                        || ctrl.initialPageSectionFormatInput.yInPx !== $event.yInPx
+                    )
+                );
+
+                const pageSectionFormatHasChanged = (
+                    ctrl.initialPageSectionFormatInput === null
+                    || formatUpdated
+                    || customSizeUpdated
+                    || orientationUpdated
+                );
+
+                if (pageSectionFormatHasChanged) {
+                    $timeout(() => {
+                        ctrl.pageSectionSettings.pageSectionFormat = $event;
+                    });
+                }
+            };
+        }
+    });
+
 }());
