@@ -335,6 +335,23 @@
                     }
                 };
 
+                function handleKeyDown(event) {
+                    // Escape key
+                    if (event.keyCode === 27) { 
+                        if (scope.state.shown) {
+                            scope.$apply(() => {
+                                scope.hide();
+                            });
+                        } 
+                    }
+                }
+                
+                angular.element(document).on('keydown', handleKeyDown);
+                
+                scope.$on("$destroy", function(){
+                    angular.element(document).off('keydown', handleKeyDown);
+                });
+                
                 scope.show = function(isImplicit) {
                     if (!scope.state.shown || isImplicit) {
                         scope.state.shown = true;
@@ -483,19 +500,173 @@
         };
     });
 
-    app.directive('appsDrawer', function(TOPBAR_DRAWER_IDS) {
+    app.directive('appsDrawer', function(TOPBAR_DRAWER_IDS, $timeout, TopbarDrawersService) {
         return {
             restrict: 'A',
             templateUrl: '/templates/widgets/topbar_drawers/apps-drawer.html',
-            link: function (scope, element, attrs) {
+            link: function(scope, element, attrs) {
+
+                var navigableItems = [];
+                var currentIndex = -1;
+
+                function updateNavigableItems() {
+                    navigableItems = [];
+                    var potentialLinks = element.find('a.master-section');
+
+                    angular.forEach(potentialLinks, function(aLink) {
+                        var aElem = angular.element(aLink);
+                        var liElem = aElem.closest('li');
+
+
+                        if (liElem.length) {
+
+                            var aVisible = true;
+                            var currentCheckElem = aElem[0];
+                            while (currentCheckElem && currentCheckElem !== element[0]) {
+                                var style = window.getComputedStyle(currentCheckElem);
+                                if (style.display === 'none' || style.visibility === 'hidden') {
+                                    aVisible = false;
+                                    break;
+                                }
+                                currentCheckElem = currentCheckElem.parentElement;
+                            }
+
+                            if (aVisible) {
+                                navigableItems.push(liElem[0]);
+                            }
+                        }
+                    });
+                }
+
+                scope.$watch('state.shown', function(newVal) {
+                    if (newVal) {
+                        $timeout(function() {
+                            updateNavigableItems();
+                            currentIndex = -1;
+                        });
+                    } else {
+                        resetFocus();
+                        currentIndex = -1;
+                    }
+                });
+
+                function resetFocus() {
+                    angular.forEach(navigableItems, function(item) {
+                        angular.element(item).removeClass('focused-apps-nav');
+                    });
+                }
+
+                function focusItem(index) {
+                    resetFocus();
+
+                    if (index >= 0 && index < navigableItems.length) {
+                        var itemToFocus = angular.element(navigableItems[index]);
+                        itemToFocus.addClass('focused-apps-nav');
+
+                        itemToFocus[0].scrollIntoView({ block: 'nearest', inline: 'nearest' });
+
+                        currentIndex = index;
+                    }
+                }
+
+                scope.handleKeydown = function(event) {
+                    if (!scope.state.shown || navigableItems.length === 0) return;
+                    var numItems = navigableItems.length;
+
+                    switch (event.keyCode) {
+                        // Tab or Shift+Tab -> we close the drawer and focus the next or previous focusable element
+                        case 9:
+                            {
+                                event.preventDefault();
+                                const isShift = event.shiftKey;
+                                scope.hide();
+                                $timeout(() => {
+                                    const triggerButton = document.querySelector('[apps-drawer-navigation]');
+                                    if (triggerButton) {
+                                        triggerButton.focus();
+
+                                        $timeout(() => {
+                                            const focusables = Array.from(document.querySelectorAll('a, button, input, [tabindex]:not([tabindex="-1"])'))
+                                                .filter(el => el.offsetParent !== null);
+
+                                            const currentIndex = focusables.indexOf(triggerButton);
+                                            const nextIndex = isShift ? currentIndex - 1 : currentIndex + 1;
+
+                                            const target = focusables[nextIndex];
+                                            if (target) target.focus();
+                                        }, 0);
+                                    }
+                                }, 0);
+                                return;
+                            }
+
+                        // Up and Down arrows -> we change the current item
+                        case 38:
+                            event.preventDefault();
+                            if (currentIndex === -1 && numItems > 0) {
+                                currentIndex = numItems - 1;
+                            } else {
+                                currentIndex = (currentIndex - 1 + numItems) % numItems;
+                            }
+                            break;
+                        case 40:
+                            event.preventDefault();
+                            if (currentIndex === -1 && numItems > 0) {
+                                currentIndex = 0;
+                            } else {
+                                currentIndex = (currentIndex + 1) % numItems;
+                            }
+                            break;
+
+                        // Left and Right arrows are not handled here, as they are handled by the apps navigation
+                        case 37:
+                        case 39:
+                            event.preventDefault();
+                            return;
+
+                        // Enter and Space -> we click the current item
+                        case 13:
+                        case 32:
+                            event.preventDefault();
+                            if (currentIndex >= 0 && currentIndex < numItems) {
+                                var item = angular.element(navigableItems[currentIndex]);
+                                var link = item.find('a.master-section');
+                                if (link.length) {
+
+                                    link[0].click();
+                                }
+                            }
+                            return;
+                    }
+                    focusItem(currentIndex);
+                };
+
                 scope.registerDrawer({
                     id: TOPBAR_DRAWER_IDS.APPS,
+                    handleKeydown: scope.handleKeydown,
+
+                    refreshItems: function() {
+                        if (scope.state.shown) {
+                            var oldCurrentItem = navigableItems[currentIndex];
+                            updateNavigableItems();
+                            var newIdx = navigableItems.indexOf(oldCurrentItem);
+                            if (currentIndex !== -1) {
+                                currentIndex = (newIdx !== -1) ? newIdx : (navigableItems.length > 0 ? 0 : -1);
+                                const shouldFocus = currentIndex !== -1;
+                                if (shouldFocus) {
+                                    focusItem(currentIndex);
+                                }
+                            } else {
+                                resetFocus();
+                            }
+                        }
+                    }
                 });
 
                 // when clicking on a link in the menu, hide the menu right away so that it doesn't hide possible 'unsaved content' modals
                 scope.hideBeforeNavigate = ($event) => {
                     const containingLink = $($event.target).parents('a');
-                    if(containingLink.length) {
+                    if (containingLink.length) {
                         scope.hide();
                     }
                 };
@@ -552,9 +723,13 @@
             templateUrl : '/templates/widgets/topbar_drawers/opals-help-drawer.html',
             link : function(scope) {
                 scope.initialDisplay = false;
+                let lastFocusedElementBeforeDrawerOpened = null; 
 
                 const show = function(isImplicit) {
                     if (!scope.state.shown || isImplicit) {
+                        if (!isImplicit) {
+                            lastFocusedElementBeforeDrawerOpened = document.activeElement;
+                        }
                         if (!scope.initialDisplay) {
                             scope.initialDisplay = true;
                         }
@@ -577,6 +752,13 @@
                                 PageSpecificTourService.displayReopenTutorialPopup();
                                 setTimeout(() => QuestionnaireService.setIsFromQuestionnaire(false)); // timeout is needed so it's still true when showing the Reopen Tutorial popup
                             }
+
+                            if (lastFocusedElementBeforeDrawerOpened) {
+                                $timeout(() => { 
+                                    lastFocusedElementBeforeDrawerOpened.focus();
+                                    lastFocusedElementBeforeDrawerOpened = null; 
+                                }, 0); 
+                            }
                         }
                     }
                 };
@@ -922,13 +1104,15 @@
                         scope.needToDisplayWarningPopUp = true;
                     }
                 }
-                $rootScope.$watch('appConfig.login',function(nv) {
+                const appConfigLoginUnsubscribe = $rootScope.$watch('appConfig.login',function(nv) {
                     scope.currentUserLogin = nv;
                 });
-                $rootScope.$on('conflict-list-changed',function() {
+                scope.$on('$destroy', appConfigLoginUnsubscribe);
+                const conflictListChangedUnsubscribe = $rootScope.$on('conflict-list-changed',function() {
                     scope.conflicts = ConflictDetector.listConflicts();
                     updateWarningState();
                 });
+                scope.$on('$destroy', conflictListChangedUnsubscribe);
                 scope.conflicts = ConflictDetector.listConflicts();
                 scope.needToDisplayWarningPopUp = true;
                 updateWarningState();
