@@ -18,7 +18,6 @@ import time
 
 import numpy as np
 from sklearn.model_selection import train_test_split
-import pandas as pd
 
 from dataiku.base import remoterun
 from dataiku.base.folder_context import build_folder_context
@@ -28,6 +27,7 @@ from dataiku.core import doctor_constants
 from dataiku.core import intercom
 from dataiku.core.doctor_constants import TARGET_VARIABLE, TIME_VARIABLE
 from dataiku.core.percentage_progress import PercentageProgress
+from dataiku.core.saved_model import get_source_dss_version
 from dataiku.doctor import step_constants
 from dataiku.doctor import utils
 from dataiku.doctor.clustering.clustering_scorer import ClusteringModelScorer
@@ -55,12 +55,6 @@ from dataiku.doctor.prediction.common import prepare_multiframe
 from dataiku.doctor.prediction.common import regridify_optimized_params
 from dataiku.doctor.prediction.common import PredictionAlgorithmNaNSupport
 from dataiku.doctor.prediction.metric import MAPE
-from dataiku.doctor.timeseries.models import TimeseriesForecastingAlgorithm
-from dataiku.doctor.timeseries.posttraining.interactive_scenarios_handler import TimeseriesInteractiveScenariosHandler
-from dataiku.doctor.timeseries.preparation.preprocessing import TimeseriesPreprocessing, get_windows_list, \
-    add_rolling_windows_for_training, add_rolling_windows_for_scoring
-from dataiku.doctor.timeseries.score.scoring_handler import resample_for_scoring
-from dataiku.doctor.timeseries.train.training_handler import resample_for_training
 from dataiku.doctor.utils.gpu_execution import log_nvidia_smi_if_use_gpu
 from dataiku.doctor.utils.model_io import to_pkl, from_pkl
 from dataiku.doctor.prediction.decisions_and_cuts import DecisionsAndCuts
@@ -90,16 +84,19 @@ from dataiku.doctor.utils.split import load_test_set
 from dataiku.doctor.utils.split import load_train_set
 from dataikuscoring.utils.prediction_result import ClassificationPredictionResult
 from dataikuscoring.utils.prediction_result import PredictionResult
-from dataiku.doctor.timeseries.preparation.preprocessing import get_external_features
-from dataiku.doctor.timeseries.utils import ModelForecast
-from dataiku.doctor.timeseries.perf.model_perf import TimeseriesModelScorer
-from dataiku.doctor.timeseries.utils import get_dataframe_of_timeseries_identifier, SINGLE_TIMESERIES_IDENTIFIER
 
 preprocessing_listener = ProgressListener()
 global_modeling_sets = []
 
 logger = logging.getLogger(__name__)
 
+if sys.version_info >= (3,):
+    # timeseries package does not support 2.7
+    from dataiku.doctor.timeseries.train.training_handler import resample_for_training
+    from dataiku.doctor.timeseries.models import TimeseriesForecastingAlgorithm
+    from dataiku.doctor.timeseries.preparation.preprocessing import TimeseriesPreprocessing, get_windows_list, \
+        add_rolling_windows_for_training
+    from dataiku.doctor.timeseries.posttraining.permutation_importance import compute_post_train_permutation_importance
 
 def _list_commands():
     current_module = sys.modules[__name__]
@@ -431,7 +428,7 @@ def compute_learning_curve(model_folder, preprocessing_folder, split_desc, split
     regridified_modeling_params = regridify_optimized_params(resolved_params, modeling_params)
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")  # within pp1/m1 ... what ?
     ml_overrides_params = ml_overrides_params_from_model_folder(model_folder_context)
-    nan_support = PredictionAlgorithmNaNSupport(modeling_params, preprocessing_params)
+    nan_support = PredictionAlgorithmNaNSupport(modeling_params, preprocessing_params, source_dss_version=get_source_dss_version(model_folder_context))
 
     split_params = split_desc["params"]
     n_folds = None
@@ -809,7 +806,7 @@ def create_ensemble(split_desc, core_params, model_folder, preprocessing_folder,
         prep_folder_context = preprocessing_folder_contexts[0]
         rppp = prep_folder_context.read_json("rpreprocessing_params.json")
         collector_data = prep_folder_context.read_json("collector_data.json")
-        nan_support = PredictionAlgorithmNaNSupport(ensemble_params["modeling_params"][0], rppp)
+        nan_support = PredictionAlgorithmNaNSupport(ensemble_params["modeling_params"][0], rppp, source_dss_version=get_source_dss_version(model_folder_contexts[0]))
         preprocessing_handler = PredictionPreprocessingHandler.build(core_params, rppp, prep_folder_context, nan_support=nan_support)
         preprocessing_handler.collector_data = collector_data
         pipe = preprocessing_handler.build_preprocessing_pipeline(with_target=True)
@@ -919,21 +916,21 @@ def compute_timeseries_residuals(job_id, split_desc, core_params, preprocessing_
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
     listener = ProgressListener()
     modeling_params = model_folder_context.read_json("rmodeling_params.json")
-    full_timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener)
+    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
+    full_timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener, algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features())
     split_folder_context = build_folder_context(split_folder)
     full_df = load_train_set(core_params, preprocessing_params, split_desc, "full",
                    split_folder_context, use_diagnostics=False)
 
     resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
     optimized_modeling_params = regridify_optimized_params(resolved_params, modeling_params)
-    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
     full_df = resample_for_training(
         full_df,
         split_desc["schema"],
         preprocessing_params[doctor_constants.TIMESERIES_SAMPLING],
         core_params,
         preprocessing_params,
-        modeling_params.get("isShiftWindowsCompatible", False),
+        algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features(),
         modeling_params["metrics"]["evaluationMetric"] == MAPE.name,
     )
 
@@ -944,7 +941,7 @@ def compute_timeseries_residuals(job_id, split_desc, core_params, preprocessing_
     transformed_full_df = full_timeseries_preprocessing.fit_and_process(
         full_df,
         step_constants.ProcessingStep.STEP_PREPROCESS_FULL,
-        algorithm.USE_GLUON_TS,
+        algorithm.ONE_MODEL_FOR_MULTIPLE_TS,
         save_data=False,
     )
     clf = from_pkl(model_folder_context)
@@ -957,153 +954,12 @@ def compute_timeseries_residuals(job_id, split_desc, core_params, preprocessing_
     clf.compute_residuals(transformed_full_df, min_size_for_scoring, residuals_model_folder_context, PercentageProgress(job_id))
     return "ok"
 
-
-def compute_timeseries_interactive_scoring_creation(job_id, split_desc, core_params, preprocessing_folder, model_folder, split_folder, fmi,
-                                 modellike_folder=None, computation_parameters=None, postcompute_folder=None,
-                                 train_split_desc=None, train_split_folder=None):
-
-    computation_parameters = computation_parameters or {}
-    target_timeseries_identifier = computation_parameters.get('timeseriesIdentifier')
-    source_scenario_id = computation_parameters.get('scenarioId')
-    start_date_str = computation_parameters.get('startDate')
-    scenario_name = computation_parameters.get('scenarioName')
-
-    model_folder_context = build_folder_context(model_folder)
-    preprocessing_folder_context = build_folder_context(preprocessing_folder)
-    preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
-    split_folder_context = build_folder_context(split_folder)
-    full_df = load_train_set(core_params, preprocessing_params, split_desc, "full",
-                             split_folder_context, use_diagnostics=False)
-
-    modeling_params = model_folder_context.read_json("rmodeling_params.json")
-    resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
-
-    external_features = get_external_features(preprocessing_params, modeling_params.get("isShiftWindowsCompatible", False))
-    if len(external_features) == 0:
-        raise ValueError("The model doesn't use any external features.")
-    full_df = resample_for_scoring(
-        full_df,
-        split_desc["schema"],
-        preprocessing_params[doctor_constants.TIMESERIES_SAMPLING],
-        core_params,
-        preprocessing_params,
-        external_features,
-        modeling_params.get("isShiftWindowsCompatible", False),
-        separate_external_features=True,
-    )
-
-    # We retrieve only identifiers that we trained on
-    trained_models_identifiers = list(model_folder_context.read_json("forecasts.json.gz")["perTimeseries"].keys())
-    if target_timeseries_identifier in trained_models_identifiers:
-        interactive_scenarios_handler = TimeseriesInteractiveScenariosHandler(model_folder_context, resolved_params, preprocessing_params, core_params, full_df)
-        interactive_scenarios_handler.create_scenario(target_timeseries_identifier, source_scenario_id, pd.to_datetime(start_date_str), scenario_name)
-        interactive_scenarios_handler.dump_identifiers_mapping()
-    else:
-        logger.info("No model for timeseries identifier %s." % target_timeseries_identifier)
-    return "ok"
-
-
-def compute_timeseries_interactive_scoring_computation(job_id, split_desc, core_params, preprocessing_folder, model_folder, split_folder, fmi,
-                                                    modellike_folder=None, computation_parameters=None, postcompute_folder=None,
-                                                    train_split_desc=None, train_split_folder=None):
-    model_folder_context = build_folder_context(model_folder)
-    preprocessing_folder_context = build_folder_context(preprocessing_folder)
-    preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
-    split_folder_context = build_folder_context(split_folder)
-    modeling_params = model_folder_context.read_json("rmodeling_params.json")
-    resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
-
-    metrics_params = modeling_params["metrics"]
-
-    listener = ProgressListener()
-    timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener)
-    clf = from_pkl(model_folder_context)
-    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
-    fit_before_predict = algorithm.should_fit_before_predict()
-
-    interactive_scoring_model_folder_context = model_folder_context.get_subfolder_context("interactive-scoring-analysis")
-    interactive_scoring_model_folder_context.create_if_not_exist()
-
-    full_df = load_train_set(core_params, preprocessing_params, split_desc, "full",
-                             split_folder_context, use_diagnostics=False)
-    external_features = get_external_features(preprocessing_params, modeling_params.get("isShiftWindowsCompatible", False))
-    full_df = resample_for_scoring(
-        full_df,
-        split_desc["schema"],
-        preprocessing_params[doctor_constants.TIMESERIES_SAMPLING],
-        core_params,
-        preprocessing_params,
-        external_features,
-        modeling_params.get("isShiftWindowsCompatible", False),
-        separate_external_features=True,
-        )
-
-    # Windowing is performed once and for all on the full dataframe
-    windows_list = get_windows_list(preprocessing_params) if modeling_params.get("isShiftWindowsCompatible", False) else []
-    full_df = add_rolling_windows_for_training(full_df, core_params, windows_list, preprocessing_params, preprocessing_folder_context)
-
-    interactive_scenarios_handler = TimeseriesInteractiveScenariosHandler(model_folder_context, resolved_params, preprocessing_params, core_params, full_df)
-
-    identifier = computation_parameters['timeseriesIdentifier']
-
-    identifier_full_df = get_dataframe_of_timeseries_identifier(full_df, identifier)
-    preprocess_on_resampled_df = algorithm.USE_GLUON_TS
-    timeseries_preprocessing.load_resources()
-    timeseries_preprocessing.create_timeseries_preprocessing_handlers(identifier_full_df, preprocess_on_resampled_df, use_saved_resources=True)
-
-    transformed_full_df = timeseries_preprocessing.process(
-        identifier_full_df,
-        step_constants.ProcessingStep.STEP_PREPROCESS_TRAIN,
-        preprocess_on_resampled_df
-    )
-
-    date_format='%Y-%m-%dT%H:%M:%S.%fZ'
-    scenarios_metadata = interactive_scenarios_handler.get_scenarios_metadata(identifier)
-    for scenario_id, scenario_name in scenarios_metadata["names"].items():
-        scenario_df = interactive_scenarios_handler.get_scenario_df(identifier, scenario_id)
-        scenario_df[core_params[TARGET_VARIABLE]] = 0
-        scenario_df[core_params[TIME_VARIABLE]] = pd.to_datetime(scenario_df[core_params[TIME_VARIABLE]])
-        if identifier != SINGLE_TIMESERIES_IDENTIFIER:
-            for k, v in json.loads(identifier).items():
-                scenario_df[k] = v
-        for external_feature in external_features:
-            if external_feature not in scenario_df.columns:
-                scenario_df[external_feature] = pd.Series(None, index=scenario_df.index, dtype=full_df[external_feature].dtype)
-
-        # Process each scenario separately
-        historical_df_subset = transformed_full_df[pd.to_datetime(identifier_full_df[core_params[doctor_constants.TIME_VARIABLE]]) < np.datetime64(scenario_df[core_params[doctor_constants.TIME_VARIABLE]].iloc[0])]
-
-        # Process the updated_test_df for the current scenario
-        scenario_df = add_rolling_windows_for_scoring(scenario_df, core_params, windows_list, preprocessing_params, preprocessing_folder_context)
-        transformed_scenario_df = timeseries_preprocessing.process(
-            scenario_df,
-            step_constants.ProcessingStep.STEP_PREPROCESS_TEST,
-            preprocess_on_resampled_df
-        )
-
-        model_scorer = TimeseriesModelScorer.build(core_params, metrics_params, use_external_features=True)
-        timeseries_forecasts = model_scorer.predict_all_test_timesteps(clf, historical_df_subset, transformed_scenario_df, fit_before_predict)[identifier]
-        forecasts = {
-            "forecast": timeseries_forecasts[ModelForecast.FORECAST_VALUES],
-            "forecastTime": timeseries_forecasts[ModelForecast.TIMESTAMPS],
-            "quantiles": []
-        }
-        for idx, q in enumerate(model_scorer.quantiles):
-            forecasts["quantiles"].append({
-                "forecast": timeseries_forecasts[ModelForecast.QUANTILES_FORECASTS][idx],
-                "quantile": q
-            })
-        serializable_forecasts = model_scorer.remove_nanif_in_one_forecast(forecasts)
-        scenarios_forecasts = {
-            "forecastTime": transformed_scenario_df[core_params[doctor_constants.TIME_VARIABLE]].astype(str).values,
-            "groundTruthTime": historical_df_subset[core_params[doctor_constants.TIME_VARIABLE]][-max(2, len(scenario_df)):].dt.strftime(date_format).values,
-            "groundTruth": historical_df_subset[core_params[doctor_constants.TARGET_VARIABLE]][-max(2, len(scenario_df)):].values,
-        }
-        scenarios_forecasts["forecast"] = serializable_forecasts["forecast"]
-        scenarios_forecasts["quantiles"] = serializable_forecasts["quantiles"]
-        interactive_scenarios_handler.write_scenarios(scenarios_forecasts, identifier, scenario_id)
-
-    return "ok"
+def compute_timeseries_permutation_importance_computation(job_id, split_desc, core_params, preprocessing_folder, model_folder, split_folder, fmi,
+                                                          modellike_folder=None, computation_parameters=None, postcompute_folder=None,
+                                                          train_split_desc=None, train_split_folder=None):
+    return compute_post_train_permutation_importance(job_id, split_desc, core_params, preprocessing_folder, model_folder, split_folder, fmi,
+                                                     modellike_folder, computation_parameters, postcompute_folder,
+                                                     train_split_desc, train_split_folder)
 
 
 # This is weird, right ?! This command will re-run the training, but from the training recipe, not the one from the LAB,
