@@ -21,7 +21,7 @@ from dataiku.doctor.timeseries.preparation.preprocessing import get_external_fea
 from dataiku.doctor.timeseries.preparation.preprocessing import get_filtered_features
 from dataiku.doctor.timeseries.preparation.preprocessing import resample_timeseries
 from dataiku.doctor.timeseries.preparation.resampling.utils import get_frequency
-from dataiku.doctor.timeseries.utils import FOLD_ID_COLUMN, log_df
+from dataiku.doctor.timeseries.utils import FOLD_ID_COLUMN, log_df, get_dataframe_of_timeseries_identifier
 from dataiku.doctor.timeseries.utils import FORECAST_COLUMN
 from dataiku.doctor.timeseries.utils import JSONForecast
 from dataiku.doctor.timeseries.utils import SINGLE_TIMESERIES_IDENTIFIER
@@ -63,7 +63,7 @@ class TimeseriesTrainingHandler(object):
         with self.listener.push_step(step_name):
             log_df(logger, train_df, self.time_variable, fold_id, "Training model on")
             estimator.fit(train_df, external_features=preprocessed_external_features, shift_map=shift_map)
-            
+
         if save_model:
             actual_params = self.algorithm.get_actual_params(modeling_params, estimator, fit_params=None)
             with self.listener.push_step(step_constants.ProcessingStep.STEP_SAVING):
@@ -77,11 +77,27 @@ class TimeseriesTrainingHandler(object):
 
         if score_model and test_df is not None:
             with self.listener.push_step(step_constants.ProcessingStep.STEP_SCORING):
-                log_df(logger, test_df, self.time_variable, fold_id, "Scoring model on")
                 fit_before_predict = self.algorithm.should_fit_before_predict()
+                if fit_before_predict:
+                    if self._max_number_of_horizons_in_test(historical_df, test_df) < 2:
+                        # If there is a single horizon in the test set we don't need to refit before predict and reuse training fit
+                        # When train_df and test_df are contiguous, historical_df will be equal to train_df, and the refit is not needed
+                        # When there is a gap between train_df and test_df (custom interval), historical_df will be larger than train_df,
+                        # but skipping mandatory refit, the model will consider them to be contiguous during training.
+                        fit_before_predict = False
+
+                log_df(logger, test_df, self.time_variable, fold_id, "Scoring model on")
                 forecasts_by_timeseries = self.model_scorer.predict_all_test_timesteps(estimator, historical_df, test_df, fit_before_predict)
                 self.model_scorer.score(historical_df, test_df, forecasts_by_timeseries, fold_id, append_forecasts=True, append_scores=True)
 
+    def _max_number_of_horizons_in_test(self, historical_df, test_df):
+        max_nb_horizons = 0
+        for timeseries_identifier, _ in timeseries_iterator(historical_df, self.timeseries_identifier_columns):
+            test_length_for_timeseries_identifier = len(get_dataframe_of_timeseries_identifier(test_df, timeseries_identifier).index)
+            nb_horizons_for_timeseries_identifier = (test_length_for_timeseries_identifier - self.prediction_length) // self.model_scorer.prediction_offset + 1
+            max_nb_horizons = max(nb_horizons_for_timeseries_identifier, max_nb_horizons)
+        return max_nb_horizons
+
     def save_intrinsic_scores_and_forecasts(self, full_df, modeling_params, preprocessing_params, estimator):
         initial_intrinsic_perf_data = get_initial_intrinsic_perf_data(full_df.to_numpy(), False)
 
@@ -230,7 +246,7 @@ class TimeseriesTrainingHandler(object):
 
         ordered_columns =  (self.timeseries_identifier_columns or []) + [self.time_variable]
         if self.use_external_features:
-            ordered_columns.extend(get_external_features(preprocessing_params))
+            ordered_columns.extend(get_external_features(preprocessing_params, self.algorithm))
         if multiple_folds:
             ordered_columns.append(FOLD_ID_COLUMN)
         ordered_columns.extend([self.target_variable, FORECAST_COLUMN])
@@ -270,9 +286,9 @@ class TimeseriesTrainingHandler(object):
         self.model_intrinsic_perf.update(data)
 
 
-def resample_for_training(df, schema, resampling_params, core_params, preprocessing_params, supports_shifts, compute_zero_target_ratio_diagnostic):
+def resample_for_training(df, schema, resampling_params, core_params, preprocessing_params, supports_past_only_features, compute_zero_target_ratio_diagnostic):
     """Resample the target and the external features together"""
-    include_roles = ["TARGET", "INPUT", "INPUT_PAST_ONLY"] if supports_shifts else ["TARGET", "INPUT"]
+    include_roles = ["TARGET", "INPUT", "INPUT_PAST_ONLY"] if supports_past_only_features else ["TARGET", "INPUT"]
     numerical_columns = get_filtered_features(preprocessing_params, include_types=["NUMERIC"], include_roles=include_roles)
     categorical_columns = get_filtered_features(preprocessing_params, exclude_types=["NUMERIC"], include_roles=include_roles)
 
