@@ -2,7 +2,13 @@ import logging
 from copy import deepcopy
 from enum import Enum
 from transformers import PreTrainedTokenizer, PreTrainedTokenizerFast
-from vllm.transformers_utils.tokenizers.mistral import MistralTokenizer
+
+from dataiku.base.utils import package_is_at_least_no_import
+if package_is_at_least_no_import("vllm", "0.12.0"):
+    # import moved in https://github.com/vllm-project/vllm/pull/29693
+    from vllm.tokenizers.mistral import MistralTokenizer
+else:
+    from vllm.transformers_utils.tokenizers.mistral import MistralTokenizer
 from typing import List, Optional, Union
 
 try:
@@ -24,7 +30,7 @@ class SystemPromptSupport(Enum):
 
 # These templates are possibly incorrect , but it doesn't matter much since only old models don't come with a chat template. This is pure legacy code.
 FALCON_JINJA_TEMPLATE = "{% for message in messages %}{% if message.role == 'system' %}>>CONTEXT<<{{ message.content }}\n{% elif message.role == 'user' %}>>QUESTION<<{{ message.content }}\n{% else %}>>ANSWER<<{{ message.content }}\n{% endif %}{% endfor %}"
-MPT_DOLLY_JINJA_TEMPLATE = "{% for message in messages %}{% if message.role == 'system' %}{{ message.content }}\n{% elif message.role == 'user' %}### Instruction:\n{{ message.content }}\n{% else %}### Response:\n{{ message.content }}\n{% endif %}{% endfor %}"
+MPT_JINJA_TEMPLATE = "{% for message in messages %}{% if message.role == 'system' %}{{ message.content }}\n{% elif message.role == 'user' %}### Instruction:\n{{ message.content }}\n{% else %}### Response:\n{{ message.content }}\n{% endif %}{% endfor %}"
 
 
 class ChatTemplateRenderer(object):
@@ -106,6 +112,11 @@ class ChatTemplateRenderer(object):
         tools = tools or None  # ensure we replace [] with None for goog behaviour of vllm/transformers method calls
 
         if self.chat_template_override:
+            # When using a Mistral tokenizer, the chat template cannot be overriden. It used to be a warning
+            # but it is an error since https://github.com/vllm-project/vllm/pull/26358.
+            if isinstance(self.tokenizer, MistralTokenizer):
+                logger.warning("Custom chat template cannot be used with mistral tokenizer")
+                return None
             logger.info("Using user's custom chat template.")
             return self.chat_template_override
 
@@ -137,23 +148,16 @@ class ChatTemplateRenderer(object):
         """
         Return the chat template (jinja2 format) used to render the prompt.
         """
-        if chat_template := self._get_chat_template(tools):
-            return chat_template
 
         # Fallbacks
-        if self.hf_handling_mode == "TEXT_GENERATION_DOLLY":
-            logger.info("Using Dolly template")
-            return MPT_DOLLY_JINJA_TEMPLATE
         if self.hf_handling_mode == "TEXT_GENERATION_FALCON":
             logger.info("Using Falcon template")
             return FALCON_JINJA_TEMPLATE
         if self.hf_handling_mode == "TEXT_GENERATION_MPT":
             logger.info("Using MPT template")
-            return MPT_DOLLY_JINJA_TEMPLATE
+            return MPT_JINJA_TEMPLATE
 
-        # It doesn't matter what we set here (only old/bad models don't have a chat template)
-        logger.info("Using default template as fallback")
-        return MPT_DOLLY_JINJA_TEMPLATE
+        return self._get_chat_template(tools)
 
     def render(self, messages: List[ChatMessage]):
         """
@@ -367,14 +371,12 @@ class ChatTemplateRenderer(object):
                 new_messages.append(current_message)
                 current_message = deepcopy(message)
             else:
-                if "content" in message and message["content"] is not None:
-                    if "content" in current_message and current_message["content"]:
-                        current_message["content"] += "\n"
-                    else:
-                        current_message["content"] = ""
-                    current_message["content"] += message["content"]
-                if "parts" in message and message["parts"] is not None:
-                    current_message["parts"] = current_message.get("parts", []) or []
+                if "content" in current_message:
+                    text = current_message.pop("content")
+                    current_message["parts"] = [{"type": "TEXT", "text": text}] if text else []
+                if message.get("content"):
+                    current_message["parts"].extend([{"type": "TEXT", "text": message["content"] }])
+                if message.get("parts"):
                     current_message["parts"].extend(message["parts"])
 
         if current_message is not None:
