@@ -99,20 +99,31 @@ def get_node_type():
         return 'design'
 
 # keep in sync with the method in dataiku/code_studio/__init__.py
-def get_dataiku_user_uid():
+def _get_container_property_from_config(property_name, default_value):
     try:
         path = osp.join(DIP_HOME, "config/dip.properties")
         if not os.path.exists(path):
-            return "500"
+            return default_value
         with open(path, "r") as f:
             for line in f.readlines():
-                match = re.match(r"^dku.container.dataiku.uid\s*=\s*(\w+)$", line)
+                match = re.match(f"^dku.container.dataiku.{property_name}\s*=\s*(\w+)$", line)
                 if match:
                     return match.group(1)
     except Exception as e:
         logging.error("Could not read dip properties json file", exc_info=e)
-    return "500"
+    return default_value
 
+def get_dataiku_user_uid():
+    return _get_container_property_from_config("uid", "500")
+
+def get_dataiku_user_uid_gid():
+    uid = get_dataiku_user_uid()
+    gid = _get_container_property_from_config("gid", None)
+    return f"{uid}:{gid}" if gid is not None else uid
+
+def get_groupadd_gid_arg():
+    gid = _get_container_property_from_config("gid", None)
+    return "" if gid is None else f"-g {gid}"
 
 def compute_default_tag(image_type):
     """Computes the default tag that we'll write. This logic must match the one in DSS"""
@@ -335,10 +346,16 @@ RUN dnf -y install python3.12-devel && dnf clean all
         if opts.py313:
             if self.opts.distrib == 'almalinux8':
                 raise Exception("Python 3.13 is not supported on AlmaLinux 8, please remove the --with-py313 option")
-            self.copy_to_buildenv(osp.join(DKUINSTALLDIR, "resources/container-exec/build-python313.sh"))
             self.dockerfile += """
-COPY build-python313.sh build/
-RUN build/build-python313.sh >/tmp/build-python.log && rm -f /tmp/build-python.log
+RUN dnf -y install python3.13-devel && dnf clean all
+"""
+        if opts.py314:
+            if self.opts.distrib == 'almalinux8':
+                raise Exception("Python 3.14 is not supported on AlmaLinux 8, please remove the --with-py314 option")
+            self.copy_to_buildenv(osp.join(DKUINSTALLDIR, "resources/container-exec/build-python314.sh"))
+            self.dockerfile += """
+COPY build-python314.sh build/
+RUN build/build-python314.sh >/tmp/build-python.log && rm -f /tmp/build-python.log
 """
 
     def add_r_base(self):
@@ -542,7 +559,7 @@ COPY dss-version.json /opt/dataiku/
 # Fake DIP_HOME with tmp folder for R recipes
 ENV DIP_HOME=/home/dataiku/fake_dip_home
 
-RUN groupadd -r dataiku \
+RUN groupadd -r {groupadd_gid_arg} dataiku \
     && useradd -r -g dataiku -u {uid} -d /home/dataiku dataiku \
     && mkdir fake_dip_home fake_dip_home/tmp lib lib/project lib/instance plugin \
     && chown -Rh dataiku:dataiku /home/dataiku
@@ -570,11 +587,13 @@ RUN chgrp -R 0 /home/dataiku && chmod -R 775 /home/dataiku
 ENV DKU_CONTAINER_EXEC=1
 
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 ENTRYPOINT ["/opt/dataiku/bin/python", "-m", "dataiku.container.runner"]
-""".format(uid=get_dataiku_user_uid())
+""".format(uid=get_dataiku_user_uid(),
+           uid_gid=get_dataiku_user_uid_gid(),
+           groupadd_gid_arg=get_groupadd_gid_arg())
         if self.opts.dockerfile_append:
             self.append_to_dockerfile(self.opts.dockerfile_append)
 
@@ -620,7 +639,7 @@ class SparkExecImageBuilder(NonAPIExecImageBuilder):
 
         # Final setup
         self.dockerfile += """
-RUN groupadd -r dataiku \
+RUN groupadd -r {groupadd_gid_arg} dataiku \
     && useradd -r -g dataiku -u {uid} -d /home/dataiku dataiku \
     && mkdir -p /home/dataiku && chown dataiku:dataiku /home/dataiku
 
@@ -632,11 +651,13 @@ WORKDIR /home/dataiku
 RUN chgrp -R 0 /home/dataiku && chmod -R 775 /home/dataiku
 
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 ENTRYPOINT ["/opt/spark/entrypoint.sh"]
-""".format(uid=get_dataiku_user_uid())
+""".format(uid=get_dataiku_user_uid(),
+           uid_gid=get_dataiku_user_uid_gid(),
+           groupadd_gid_arg=get_groupadd_gid_arg())
         if self.opts.dockerfile_append:
             self.append_to_dockerfile(self.opts.dockerfile_append)
 
@@ -694,7 +715,11 @@ class KitImageBuilder(CompleteImageBuilder):
 
     # Comes in addition to DEFAULT_ALMA_SYSPACKAGES
     KIT_ALMA_SYSPACKAGES = [
-        "acl", "java-17-openjdk-headless", "dejavu-sans-fonts", "freetype", "fontconfig"
+        "acl",
+        "java-17-openjdk-headless",
+        "dejavu-sans-fonts",
+        "freetype",
+        "fontconfig",
     ]
 
     def move_to_readonly_data(self, *subdirs):
@@ -716,16 +741,18 @@ MAINTAINER Dataiku <dss@dataiku.com>
 ENV SHELL "/bin/bash"
 ENV TERM 1
 ENV LANG en_us.utf8
-RUN groupadd -r dataiku \
+RUN groupadd -r {groupadd_gid_arg} dataiku \
     && useradd -r -g dataiku -u {uid} -d /home/dataiku dataiku \
     && mkdir /home/dataiku \
     && chown -Rh dataiku:dataiku /home/dataiku
-""".format(uid=get_dataiku_user_uid())
+""".format(
+    uid=get_dataiku_user_uid(),
+    groupadd_gid_arg=get_groupadd_gid_arg())
 
     def copy_kit(self):
         # setup pod install dir
         self.dockerfile += """
-RUN mkdir -p {podinstalldir}
+RUN mkdir -p {podinstalldir} && chown -Rh dataiku:dataiku {podinstalldir}
 """.format(podinstalldir=POD_DKUINSTALLDIR)
 
         # see make-studio-package.sh
@@ -776,7 +803,7 @@ RUN mkdir -p {podinstalldir}
             os.makedirs(osp.join(self.build_env_path, 'lib', 'ivy'))
             for ivy_conf in ["common-run", "backend-run"]:
                 self.copy_to_buildenv(osp.join(DKUINSTALLDIR, 'lib', 'ivy', ivy_conf), osp.join("lib", "ivy", ivy_conf))
-            for lib_conf in ["third", "shadelib", "shims"]:
+            for lib_conf in ["third", "shadelib", "dss-shadelib", "shims"]:
                 self.copy_to_buildenv(osp.join(DKUINSTALLDIR, 'lib', lib_conf), osp.join("lib", lib_conf))
             for ivy_conf in glob.glob(osp.join(DKUINSTALLDIR, 'lib', 'ivy', 'jdbc*')):
                 self.copy_to_buildenv(ivy_conf, osp.join("lib", "ivy", osp.basename(ivy_conf)))
@@ -832,7 +859,7 @@ RUN mkdir -p {podinstalldir}
         else:
             for item in ["dist", "dss-version.json", "dss-arch.txt", "installer.sh",
                          "lib", "python", PYTHON_PACKAGES, "R", "resources", "scripts", "conda.packages"]:
-                self.dockerfile += 'COPY "%s" %s/%s\n' % (item, POD_DKUINSTALLDIR, item)
+                self.dockerfile += 'COPY --chown=dataiku:dataiku "%s" %s/%s\n' % (item, POD_DKUINSTALLDIR, item)
                 self.copy_to_buildenv(osp.join(DKUINSTALLDIR, item), item)
 
             # Remove some files that are not actually useful and that trigger stupid security scanners
@@ -846,8 +873,7 @@ RUN rm -f {podinstalldir}/resources/code-envs/python/image-classification/v1/spe
     && rm -f {podinstalldir}/resources/code-envs/python/object-detection/v1/spec/requirements.txt \
     && rm -rf {podinstalldir}/lib/ivy/govern-server-run \
     && rm -f {podinstalldir}/lib/ivy/backend-run/jnr-posix-3.0.44.jar \
-    && rm -rf {podinstalldir}/python36.packages/nbconvert* \
-    && chown -Rh dataiku:dataiku {podinstalldir}
+    && rm -rf {podinstalldir}/python36.packages/nbconvert* 
 """.format(podinstalldir=POD_DKUINSTALLDIR)
 
 class APIImageBuilder(KitImageBuilder):
@@ -884,12 +910,12 @@ RUN /bin/su - dataiku -c "%s/installer.sh -y -t api -d /home/dataiku/data -p 120
             repo_option = "-repo %s" % self.opts.cran_mirror if self.opts.cran_mirror else ""
             self.dockerfile += """
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 RUN /home/dataiku/data/bin/dssadmin install-R-integration -noDeps {repo_option} -noJupyterKernel
 USER root
-""".format(repo_option=repo_option, uid=get_dataiku_user_uid())
+""".format(repo_option=repo_option, uid_gid=get_dataiku_user_uid_gid())
 
 
 class CDEImageBuilder(KitImageBuilder):
@@ -923,8 +949,13 @@ class CDEImageBuilder(KitImageBuilder):
 RUN /bin/su - dataiku -c "%s/installer.sh -y -t design -d /home/dataiku/data -p 12000 -P python%s -j"
 """ % (POD_DKUINSTALLDIR, PYTHONVERSION)
 
+        # create the .wlock in the code-envs/desc/ so that you can create the transaction provider (even if you don't write anything)
+        self.dockerfile += """
+RUN mkdir -p /home/dataiku/data/code-envs/desc && touch /home/dataiku/data/code-envs/desc/.wlock
+"""
+
         # move outside /home/dataiku some dirs to speedup the initcontainer for readOnlyRootFilesystem
-        self.move_to_readonly_data("lib", "plugins", "R.lib", "pyenv")
+        self.move_to_readonly_data("lib", "plugins", "R.lib", "pyenv", "code-envs")
 
         if self.opts.r:
             repo_option = "-repo %s" % self.opts.cran_mirror if self.opts.cran_mirror else ""
@@ -957,11 +988,11 @@ USER root
         self.dockerfile += """
 WORKDIR /home/dataiku
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 ENTRYPOINT ["/home/dataiku/data/bin/cde"]
-""".format(uid=get_dataiku_user_uid())
+""".format(uid_gid=get_dataiku_user_uid_gid())
 
 class CDEPluginImageBuilder(BaseImageBuilder):
     """
@@ -1022,11 +1053,11 @@ class CDEPluginImageBuilder(BaseImageBuilder):
         self.dockerfile += """
 WORKDIR /home/dataiku
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 ENTRYPOINT ["/home/dataiku/data/bin/cde"]
-""".format(uid=get_dataiku_user_uid())
+""".format(uid_gid=get_dataiku_user_uid_gid())
 
     def _install_plugins(self):
         # copy plugins too
@@ -1133,13 +1164,13 @@ ENV PATH="/opt/conda/bin:$PATH"
 RUN chown -Rh dataiku:dataiku /home/dataiku/data/code-envs
 WORKDIR /home/dataiku
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 ENV HOME=/home/dataiku
 ENV VIRTUALENV_OVERRIDE_APP_DATA=/opt/dataiku/virtualenv-appdata
 RUN cd /home/dataiku/data && ./bin/dku __build_cde_plugin_code_env -names {csv_env_names} {threads_flag} && rm -rf ~/.cache/pip
 WORKDIR /opt/dataiku
 USER root
-    """.format(csv_env_names=','.join(filtered_code_env_names), threads_flag="--threads %s" % thread_override if thread_override is not None else "", uid=get_dataiku_user_uid())
+    """.format(csv_env_names=','.join(filtered_code_env_names), threads_flag="--threads %s" % thread_override if thread_override is not None else "", uid_gid=get_dataiku_user_uid_gid())
 
     @staticmethod
     def get_thread_count():
@@ -1313,6 +1344,9 @@ if __name__ == '__main__':
     parser.add_argument('--with-py313',action="store_true", dest="py313", help="Enable Python 3.13, supported on AlmaLinux 9 only (default: disabled)")
     parser.add_argument('--without-py313',action="store_false", dest="py313", help="Disable Python 3.13 (default: disabled)")
 
+    parser.add_argument('--with-py314', action="store_true", dest="py314", help="Enable Python 3.14, supported on AlmaLinux 9 only (default: disabled)")
+    parser.add_argument('--without-py314', action="store_false", dest="py314", help="Disable Python 3.14 (default: disabled)")
+
     parser.add_argument('--with-cuda', action="store_true", dest="cuda", help="Enable CUDA (default: disabled)")
     parser.add_argument('--without-cuda',action="store_false", dest="cuda", help="Disable CUDA (default: disabled)")
     parser.add_argument('--cuda-version', type=str, choices=SUPPORTED_CUDA_VERSIONS, help="CUDA version (default: " + DEFAULT_CUDA_VERSION_ALMA9 + " on AlmaLinux 9, " + DEFAULT_CUDA_VERSION_ALMA8 + " on AlmaLinux 8)")
