@@ -55,6 +55,13 @@ function createBrowser(enforceSandboxing, options) {
     // so we just add both parameters in the options provided to start the headless browser as the lib is permissive enough.
     // For puppeteer < 23.3.0.
     options.ignoreHTTPSErrors = true;
+
+    // Uncomment the following to debug puppeeter
+    //
+    // options.headless = false;
+    // options.slowMo = 300;
+    // options.devtools = true;
+
     // For puppeteer >= 23.3.0.
     // options.headless = false;
     // options.slowMo = 300;
@@ -362,6 +369,24 @@ function waitForFontsToLoad(page) {
     return page.evaluate(() => document.fonts.ready);
 }
 
+const DPI = 150;
+
+function inchesToMm(inches) {
+    return inches * 25.4;
+}
+
+function mmToInches(mm) {
+    return mm / 25.4;
+}
+
+function mmToPx(mm) {
+    return Math.round(mmToInches(mm) * DPI);
+}
+
+function pxToMm(px) {
+    return inchesToMm(px / DPI);
+}
+
 // Export constants & functions
 exports.ERR_GENERIC = ERR_GENERIC;
 exports.ERR_CREATE_BROWSER = ERR_CREATE_BROWSER;
@@ -386,3 +411,7 @@ exports.waitForElementContentToLoad = waitForElementContentToLoad;
 exports.resetElementContentToLoad = resetElementContentToLoad;
 exports.waitForFontsToLoad = waitForFontsToLoad;
 exports.checkLoading = checkLoading;
+exports.inchesToMm = inchesToMm;
+exports.mmToInches = mmToInches;
+exports.mmToPx = mmToPx;
+exports.pxToMm = pxToMm;
